@@ -1,9 +1,10 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/Modules/AdminACL.pm - ACL administration
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Modules::AdminACL;
@@ -11,10 +12,13 @@ package Kernel::Modules::AdminACL;
 use strict;
 use warnings;
 
-our $ObjectManagerDisabled = 1;
+use Kernel::System::YAML;
+use Kernel::System::Valid;
+use Kernel::System::JSON;
+use Kernel::System::DynamicField;
+use Kernel::System::ACL::DB::ACL;
 
 use Kernel::System::VariableCheck qw(:all);
-use Kernel::Language qw(Translatable);
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -23,27 +27,38 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
+    # check all needed objects
+    for my $Needed (
+        qw(ParamObject DBObject LayoutObject ConfigObject LogObject MainObject EncodeObject)
+        )
+    {
+        if ( !$Self->{$Needed} ) {
+            $Self->{LayoutObject}->FatalError( Message => "Got no $Needed!" );
+        }
+    }
+
+    # create additional objects
+    $Self->{ValidObject}        = Kernel::System::Valid->new(%Param);
+    $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new(%Param);
+    $Self->{JSONObject}         = Kernel::System::JSON->new( %{$Self} );
+    $Self->{YAMLObject}         = Kernel::System::YAML->new( %{$Self} );
+    $Self->{ACLObject}          = Kernel::System::ACL::DB::ACL->new( %{$Self} );
+
     return $Self;
 }
 
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    my $ParamObject = $Kernel::OM->Get('Kernel::System::Web::Request');
+    $Self->{Subaction} = $Self->{ParamObject}->GetParam( Param => 'Subaction' ) || '';
 
-    $Self->{Subaction} = $ParamObject->GetParam( Param => 'Subaction' ) || '';
+    my $ACLID = $Self->{ParamObject}->GetParam( Param => 'ID' ) || '';
 
-    my $ACLID = $ParamObject->GetParam( Param => 'ID' ) || '';
-
-    my $SynchronizeMessage = Translatable(
-        'ACL information from database is not in sync with the system configuration, please deploy all ACLs.'
-    );
+    my $SynchronizeMessage
+        = 'ACL information from database is not in sync with the system configuration, please deploy all ACLs.';
 
     my $SynchronizedMessageVisible = 0;
-
-    my $ACLObject = $Kernel::OM->Get('Kernel::System::ACL::DB::ACL');
-
-    if ( $ACLObject->ACLsNeedSync() ) {
+    if ( $Self->{ACLObject}->ACLsNeedSync() ) {
 
         # create a notification if system is not up to date
         $Param{NotifyData} = [
@@ -54,71 +69,112 @@ sub Run {
         $SynchronizedMessageVisible = 1;
     }
 
-    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-
     # ------------------------------------------------------------ #
     # ACLImport
     # ------------------------------------------------------------ #
     if ( $Self->{Subaction} eq 'ACLImport' ) {
 
         # challenge token check for write action
-        $LayoutObject->ChallengeTokenCheck();
+        $Self->{LayoutObject}->ChallengeTokenCheck();
 
-        my $FormID      = $ParamObject->GetParam( Param => 'FormID' ) || '';
-        my %UploadStuff = $ParamObject->GetUploadAll(
+        my $FormID = $Self->{ParamObject}->GetParam( Param => 'FormID' ) || '';
+        my %UploadStuff = $Self->{ParamObject}->GetUploadAll(
             Param  => 'FileUpload',
             Source => 'string',
         );
 
-        my $OverwriteExistingEntities = $ParamObject->GetParam( Param => 'OverwriteExistingEntities' ) || '';
+        my $OverwriteExistingEntities = $Self->{ParamObject}->GetParam( Param => 'OverwriteExistingEntities' ) || '';
 
-        my $ACLImport = $ACLObject->ACLImport(
-            Content                   => $UploadStuff{Content},
-            OverwriteExistingEntities => $OverwriteExistingEntities,
-            UserID                    => $Self->{UserID},
-        );
+        my $ACLData = $Self->{YAMLObject}->Load( Data => $UploadStuff{Content} );
 
-        if ( !$ACLImport->{Success} ) {
-            my $Message = $ACLImport->{Message}
-                || Translatable(
-                'ACLs could not be Imported due to a unknown error, please check OTRS logs for more information'
-                );
-            return $LayoutObject->ErrorScreen(
-                Message => $Message,
+        if ( ref $ACLData ne 'ARRAY' ) {
+            return $Self->{LayoutObject}->ErrorScreen(
+                Message =>
+                    "Couldn't read ACL configuration file. Please make sure the file is valid.",
             );
         }
 
-        if ( $ACLImport->{AddedACLs} ) {
+        my @UpdatedACLs;
+        my @AddedACLs;
+        my @ACLErrors;
+
+        ACL:
+        for my $ACL ( @{$ACLData} ) {
+
+            next ACL if !$ACL;
+            next ACL if ref $ACL ne 'HASH';
+
+            my @ExistingACLs = @{ $Self->{ACLObject}->ACLListGet( UserID => $Self->{UserID} ) || [] };
+            @ExistingACLs = grep { $_->{Name} eq $ACL->{Name} } @ExistingACLs;
+
+            if ( $OverwriteExistingEntities && $ExistingACLs[0] ) {
+                my $Success = $Self->{ACLObject}->ACLUpdate(
+                    %{ $ExistingACLs[0] },
+                    Name           => $ACL->{Name},
+                    Comment        => $ACL->{Comment},
+                    Description    => $ACL->{Description} || '',
+                    StopAfterMatch => $ACL->{StopAfterMatch} || 0,
+                    ConfigMatch    => $ACL->{ConfigMatch} || undef,
+                    ConfigChange   => $ACL->{ConfigChange} || undef,
+                    ValidID        => $ACL->{ValidID} || 1,
+                    UserID         => $Self->{UserID},
+                );
+
+                if ($Success) {
+                    push @UpdatedACLs, $ACL->{Name};
+                }
+                else {
+                    push @ACLErrors, $ACL->{Name};
+                }
+
+            }
+            else {
+
+                # now add the ACL
+                my $Success = $Self->{ACLObject}->ACLAdd(
+                    Name           => $ACL->{Name},
+                    Comment        => $ACL->{Comment},
+                    Description    => $ACL->{Description} || '',
+                    ConfigMatch    => $ACL->{ConfigMatch} || undef,
+                    ConfigChange   => $ACL->{ConfigChange} || undef,
+                    StopAfterMatch => $ACL->{StopAfterMatch},
+                    ValidID        => $ACL->{ValidID} || 1,
+                    UserID         => $Self->{UserID},
+                );
+
+                if ($Success) {
+                    push @AddedACLs, $ACL->{Name};
+                }
+                else {
+                    push @ACLErrors, $ACL->{Name};
+                }
+            }
+        }
+
+        my $UpdatedACLsStrg = join( ', ', @UpdatedACLs ) || '';
+        my $AddedACLsStrg   = join( ', ', @AddedACLs )   || '';
+        my $ACLErrorsStrg   = join( ', ', @ACLErrors )   || '';
+
+        if ($AddedACLsStrg) {
             push @{ $Param{NotifyData} }, {
-                Info => $LayoutObject->{LanguageObject}->Translate(
-                    'The following ACLs have been added successfully: %s',
-                    $ACLImport->{AddedACLs}
-                ),
+                Info => 'The following ACLs have been added successfully: ' . $AddedACLsStrg,
             };
         }
-        if ( $ACLImport->{UpdatedACLs} ) {
+        if ($UpdatedACLsStrg) {
             push @{ $Param{NotifyData} }, {
-                Info => $LayoutObject->{LanguageObject}->Translate(
-                    'The following ACLs have been updated successfully: %s',
-                    $ACLImport->{UpdatedACLs}
-                ),
+                Info => 'The following ACLs have been updated successfully: ' . $UpdatedACLsStrg,
             };
         }
-        if ( $ACLImport->{ACLErrors} ) {
+        if ($ACLErrorsStrg) {
             push @{ $Param{NotifyData} }, {
                 Priority => 'Error',
-                Info     => $LayoutObject->{LanguageObject}->Translate(
-                    'There where errors adding/updating the following ACLs: %s. Please check the log file for more information.',
-                    $ACLImport->{ACLErrors}
-                ),
+                Info     => 'There where errors adding/updating the following ACLs: '
+                    . $ACLErrorsStrg
+                    . '. Please check the log file for more information.',
             };
         }
 
-        if (
-            ( $ACLImport->{UpdatedACLs} || $ACLImport->{AddedACLs} )
-            && !$SynchronizedMessageVisible
-            )
-        {
+        if ( ( $UpdatedACLsStrg || $AddedACLsStrg ) && !$SynchronizedMessageVisible ) {
 
             $Param{NotifyData} = [
                 @{ $Param{NotifyData} || [] },
@@ -150,7 +206,7 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'ACLNewAction' ) {
 
         # challenge token check for write action
-        $LayoutObject->ChallengeTokenCheck();
+        $Self->{LayoutObject}->ChallengeTokenCheck();
 
         # get ACL data
         my $ACLData;
@@ -171,14 +227,14 @@ sub Run {
 
             # add server error error class
             $Error{NameServerError}        = 'ServerError';
-            $Error{NameServerErrorMessage} = Translatable('This field is required');
+            $Error{NameServerErrorMessage} = 'This field is required';
         }
 
         if ( !$GetParam->{ValidID} ) {
 
             # add server error error class
             $Error{ValidIDServerError}        = 'ServerError';
-            $Error{ValidIDServerErrorMessage} = Translatable('This field is required');
+            $Error{ValidIDServerErrorMessage} = 'This field is required';
         }
 
         # if there is an error return to edit screen
@@ -192,7 +248,7 @@ sub Run {
         }
 
         # otherwise save configuration and return to overview screen
-        my $ACLID = $ACLObject->ACLAdd(
+        my $ACLID = $Self->{ACLObject}->ACLAdd(
             Name           => $ACLData->{Name},
             Comment        => $ACLData->{Comment},
             Description    => $ACLData->{Description},
@@ -203,13 +259,13 @@ sub Run {
 
         # show error if can't create
         if ( !$ACLID ) {
-            return $LayoutObject->ErrorScreen(
-                Message => Translatable('There was an error creating the ACL'),
+            return $Self->{LayoutObject}->ErrorScreen(
+                Message => "There was an error creating the ACL",
             );
         }
 
         # redirect to edit screen
-        return $LayoutObject->Redirect( OP => "Action=$Self->{Action};Subaction=ACLEdit;ID=$ACLID" );
+        return $Self->{LayoutObject}->Redirect( OP => "Action=$Self->{Action};Subaction=ACLEdit;ID=$ACLID" );
     }
 
     # ------------------------------------------------------------ #
@@ -219,34 +275,32 @@ sub Run {
 
         # check for ACLID
         if ( !$ACLID ) {
-            return $LayoutObject->ErrorScreen(
-                Message => Translatable('Need ACLID!'),
+            return $Self->{LayoutObject}->ErrorScreen(
+                Message => "Need ACLID!",
             );
         }
 
         # get ACL data
-        my $ACLData = $ACLObject->ACLGet(
+        my $ACLData = $Self->{ACLObject}->ACLGet(
             ID     => $ACLID,
             UserID => $Self->{UserID},
         );
 
         # check for valid ACL data
         if ( !IsHashRefWithData($ACLData) ) {
-            return $LayoutObject->ErrorScreen(
-                Message => $LayoutObject->{LanguageObject}->Translate( 'Could not get data for ACLID %s', $ACLID ),
+            return $Self->{LayoutObject}->ErrorScreen(
+                Message => "Could not get data for ACLID $ACLID",
             );
         }
 
-        my $JSONObject = $Kernel::OM->Get('Kernel::System::JSON');
-
         if ( $ACLData->{ConfigMatch} ) {
-            $ACLData->{ConfigMatch} = $JSONObject->Encode(
+            $ACLData->{ConfigMatch} = $Self->{JSONObject}->Encode(
                 Data => $ACLData->{ConfigMatch},
             );
         }
 
         if ( $ACLData->{ConfigChange} ) {
-            $ACLData->{ConfigChange} = $JSONObject->Encode(
+            $ACLData->{ConfigChange} = $Self->{JSONObject}->Encode(
                 Data => $ACLData->{ConfigChange},
             );
         }
@@ -265,7 +319,7 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'ACLEditAction' ) {
 
         # challenge token check for write action
-        $LayoutObject->ChallengeTokenCheck();
+        $Self->{LayoutObject}->ChallengeTokenCheck();
 
         # get webserice configuration
         my $ACLData;
@@ -288,14 +342,14 @@ sub Run {
 
             # add server error error class
             $Error{NameServerError}        = 'ServerError';
-            $Error{NameServerErrorMessage} = Translatable('This field is required');
+            $Error{NameServerErrorMessage} = 'This field is required';
         }
 
         if ( !$GetParam->{ValidID} ) {
 
             # add server error error class
             $Error{ValidIDServerError}        = 'ServerError';
-            $Error{ValidIDServerErrorMessage} = Translatable('This field is required');
+            $Error{ValidIDServerErrorMessage} = 'This field is required';
         }
 
         # if there is an error return to edit screen
@@ -309,7 +363,7 @@ sub Run {
         }
 
         # otherwise save configuration and return to overview screen
-        my $Success = $ACLObject->ACLUpdate(
+        my $Success = $Self->{ACLObject}->ACLUpdate(
             ID             => $ACLID,
             Name           => $ACLData->{Name},
             Comment        => $ACLData->{Comment},
@@ -323,19 +377,15 @@ sub Run {
 
         # show error if can't update
         if ( !$Success ) {
-            return $LayoutObject->ErrorScreen(
-                Message => Translatable('There was an error updating the ACL'),
+            return $Self->{LayoutObject}->ErrorScreen(
+                Message => "There was an error updating the ACL",
             );
         }
 
-        if (
-            defined $ParamObject->GetParam( Param => 'ContinueAfterSave' )
-            && ( $ParamObject->GetParam( Param => 'ContinueAfterSave' ) eq '1' )
-            )
-        {
+        if ( $Self->{ParamObject}->GetParam( Param => 'ContinueAfterSave' ) eq '1' ) {
 
             # if the user would like to continue editing the ACL, just redirect to the edit screen
-            return $LayoutObject->Redirect(
+            return $Self->{LayoutObject}->Redirect(
                 OP =>
                     "Action=AdminACL;Subaction=ACLEdit;ID=$ACLID"
             );
@@ -343,7 +393,7 @@ sub Run {
         else {
 
             # otherwise return to overview
-            return $LayoutObject->Redirect( OP => "Action=$Self->{Action}" );
+            return $Self->{LayoutObject}->Redirect( OP => "Action=$Self->{Action}" );
         }
     }
 
@@ -352,9 +402,9 @@ sub Run {
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'ACLDeploy' ) {
 
-        my $Location = $Kernel::OM->Get('Kernel::Config')->Get('Home') . '/Kernel/Config/Files/ZZZACL.pm';
+        my $Location = $Self->{ConfigObject}->Get('Home') . '/Kernel/Config/Files/ZZZACL.pm';
 
-        my $ACLDump = $ACLObject->ACLDump(
+        my $ACLDump = $Self->{ACLObject}->ACLDump(
             ResultType => 'FILE',
             Location   => $Location,
             UserID     => $Self->{UserID},
@@ -362,24 +412,24 @@ sub Run {
 
         if ($ACLDump) {
 
-            my $Success = $ACLObject->ACLsNeedSyncReset();
+            my $Success = $Self->{ACLObject}->ACLsNeedSyncReset();
 
             if ($Success) {
-                return $LayoutObject->Redirect( OP => "Action=$Self->{Action}" );
+                return $Self->{LayoutObject}->Redirect( OP => "Action=$Self->{Action}" );
             }
             else {
 
                 # show error if can't set state
-                return $LayoutObject->ErrorScreen(
-                    Message => Translatable('There was an error setting the entity sync status.'),
+                return $Self->{LayoutObject}->ErrorScreen(
+                    Message => "There was an error setting the entity sync status.",
                 );
             }
         }
         else {
 
             # show error if can't synch
-            return $LayoutObject->ErrorScreen(
-                Message => Translatable('There was an error synchronizing the ACLs.'),
+            return $Self->{LayoutObject}->ErrorScreen(
+                Message => "There was an error synchronizing the ACLs.",
             );
         }
     }
@@ -390,7 +440,7 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'ACLDelete' ) {
 
         # challenge token check for write action
-        $LayoutObject->ChallengeTokenCheck();
+        $Self->{LayoutObject}->ChallengeTokenCheck();
 
         # check for ACLID
         return if !$ACLID;
@@ -400,7 +450,7 @@ sub Run {
         my $JSON;
         if ( $CheckResult->{Success} ) {
 
-            my $Success = $ACLObject->ACLDelete(
+            my $Success = $Self->{ACLObject}->ACLDelete(
                 ID     => $ACLID,
                 UserID => $Self->{UserID},
             );
@@ -410,12 +460,11 @@ sub Run {
             );
 
             if ( !$Success ) {
-                $DeleteResult{Message}
-                    = $LayoutObject->{LanguageObject}->Translate( 'ACL %s could not be deleted', $ACLID );
+                $DeleteResult{Message} = 'ACL $ACLID could not be deleted';
             }
 
             # build JSON output
-            $JSON = $LayoutObject->JSONEncode(
+            $JSON = $Self->{LayoutObject}->JSONEncode(
                 Data => {
                     %DeleteResult,
                 },
@@ -424,7 +473,7 @@ sub Run {
         else {
 
             # build JSON output
-            $JSON = $LayoutObject->JSONEncode(
+            $JSON = $Self->{LayoutObject}->JSONEncode(
                 Data => {
                     %{$CheckResult},
                 },
@@ -432,8 +481,8 @@ sub Run {
         }
 
         # send JSON response
-        return $LayoutObject->Attachment(
-            ContentType => 'application/json; charset=' . $LayoutObject->{Charset},
+        return $Self->{LayoutObject}->Attachment(
+            ContentType => 'application/json; charset=' . $Self->{LayoutObject}->{Charset},
             Content     => $JSON,
             Type        => 'inline',
             NoCache     => 1,
@@ -445,22 +494,21 @@ sub Run {
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'ACLExport' ) {
 
-        my $ACLID = $ParamObject->GetParam( Param => 'ID' ) || '';
+        my $ACLID = $Self->{ParamObject}->GetParam( Param => 'ID' ) || '';
         my $ACLData;
         my $ACLSingleData;
         my $Filename = 'Export_ACL.yml';
 
         if ($ACLID) {
 
-            $ACLSingleData = $ACLObject->ACLGet(
+            $ACLSingleData = $Self->{ACLObject}->ACLGet(
                 ID     => $ACLID,
                 UserID => 1,
             );
 
             if ( !$ACLSingleData || !IsHashRefWithData($ACLSingleData) ) {
-                return $LayoutObject->ErrorScreen(
-                    Message => $LayoutObject->{LanguageObject}
-                        ->Translate( 'There was an error getting data for ACL with ID %s', $ACLID ),
+                return $Self->{LayoutObject}->ErrorScreen(
+                    Message => "There was an error getting data for ACL with ID " . $ACLID,
                 );
             }
 
@@ -472,23 +520,18 @@ sub Run {
         }
         else {
 
-            # Get all IDs from valid table including invalid-temporarily status.
-            # See bug#13592 (https://bugs.otrs.org/show_bug.cgi?id=13592).
-            my %ValidList    = $Kernel::OM->Get('Kernel::System::Valid')->ValidList();
-            my @ValidListIDs = grep { $ValidList{$_} } sort keys %ValidList;
-
-            $ACLData = $ACLObject->ACLListGet(
+            $ACLData = $Self->{ACLObject}->ACLListGet(
                 UserID   => 1,
-                ValidIDs => \@ValidListIDs,
+                ValidIDs => [ '1', '2' ],
             );
         }
 
         # convert the ACL data hash to string
-        my $ACLDataYAML = $Kernel::OM->Get('Kernel::System::YAML')->Dump( Data => $ACLData );
+        my $ACLDataYAML = $Self->{YAMLObject}->Dump( Data => $ACLData );
 
         # send the result to the browser
-        return $LayoutObject->Attachment(
-            ContentType => 'text/html; charset=' . $LayoutObject->{Charset},
+        return $Self->{LayoutObject}->Attachment(
+            ContentType => 'text/html; charset=' . $Self->{LayoutObject}->{Charset},
             Content     => $ACLDataYAML,
             Type        => 'attachment',
             Filename    => $Filename,
@@ -502,55 +545,47 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'ACLCopy' ) {
 
         # challenge token check for write action
-        $LayoutObject->ChallengeTokenCheck();
+        $Self->{LayoutObject}->ChallengeTokenCheck();
 
         # get ACL data
-        my $ACLData = $ACLObject->ACLGet(
+        my $ACLData = $Self->{ACLObject}->ACLGet(
             ID     => $ACLID,
             UserID => $Self->{UserID},
         );
         if ( !$ACLData ) {
-            return $LayoutObject->ErrorScreen(
+            return $Self->{LayoutObject}->ErrorScreen(
                 Message => "Unknown ACL $ACLID!",
             );
         }
 
-        # Create new ACL name.
-        my $Count   = 1;
-        my $ACLName = $LayoutObject->{LanguageObject}->Translate( '%s (copy) %s', $ACLData->{Name}, $Count );
-        while (
-            $ACLObject->ACLGet(
-                Name   => $ACLName,
-                UserID => $Self->{UserID}
-            )
-            && $Count < 100
-            )
-        {
-            $ACLName =~ s/\d+$/$Count/;
-            $Count++;
-        }
+        # create new ACL name
+        my $ACLName =
+            $ACLData->{Name}
+            . ' ('
+            . $Self->{LayoutObject}->{LanguageObject}->Get('Copy')
+            . ')';
 
         # otherwise save configuration and return to overview screen
-        my $ACLID = $ACLObject->ACLAdd(
+        my $ACLID = $Self->{ACLObject}->ACLAdd(
             Name           => $ACLName,
             Comment        => $ACLData->{Comment},
             Description    => $ACLData->{Description},
             ConfigMatch    => $ACLData->{ConfigMatch} || '',
             ConfigChange   => $ACLData->{ConfigChange} || '',
             StopAfterMatch => $ACLData->{StopAfterMatch} || 0,
-            ValidID        => $ACLData->{ValidID},
+            ValidID        => '1',
             UserID         => $Self->{UserID},
         );
 
         # show error if can't create
         if ( !$ACLID ) {
-            return $LayoutObject->ErrorScreen(
-                Message => Translatable('There was an error creating the ACL'),
+            return $Self->{LayoutObject}->ErrorScreen(
+                Message => "There was an error creating the ACL",
             );
         }
 
         # return to overview
-        return $LayoutObject->Redirect( OP => "Action=$Self->{Action}" );
+        return $Self->{LayoutObject}->Redirect( OP => "Action=$Self->{Action}" );
     }
 
     # ------------------------------------------------------------ #
@@ -566,32 +601,20 @@ sub Run {
 sub _ShowOverview {
     my ( $Self, %Param ) = @_;
 
-    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-    my $ACLObject    = $Kernel::OM->Get('Kernel::System::ACL::DB::ACL');
-    my $Output       = $LayoutObject->Header();
-    $Output .= $LayoutObject->NavigationBar();
-
-    if ( $Self->{UserID} == 1 ) {
-
-        # show error notfy, don't work with user id 1
-        $Output .= $LayoutObject->Notify(
-            Priority => 'Error',
-            Info =>
-                Translatable('Please note that ACL restrictions will be ignored for the Superuser account (UserID 1).'),
-        );
-    }
+    my $Output = $Self->{LayoutObject}->Header();
+    $Output .= $Self->{LayoutObject}->NavigationBar();
 
     # show notifications if any
     if ( $Param{NotifyData} ) {
         for my $Notification ( @{ $Param{NotifyData} } ) {
-            $Output .= $LayoutObject->Notify(
+            $Output .= $Self->{LayoutObject}->Notify(
                 %{$Notification},
             );
         }
     }
 
     # get ACL list
-    my $ACLList = $ACLObject->ACLList( UserID => $Self->{UserID} );
+    my $ACLList = $Self->{ACLObject}->ACLList( UserID => $Self->{UserID} );
 
     if ( IsHashRefWithData($ACLList) ) {
 
@@ -601,17 +624,16 @@ sub _ShowOverview {
         # get each ACLs data
         for my $ACLID (@ACLIDsSorted) {
 
-            my $ACLData = $ACLObject->ACLGet(
+            my $ACLData = $Self->{ACLObject}->ACLGet(
                 ID     => $ACLID,
                 UserID => $Self->{UserID},
             );
 
             # set the valid state
-            $ACLData->{ValidID}
-                = $Kernel::OM->Get('Kernel::System::Valid')->ValidLookup( ValidID => $ACLData->{ValidID} );
+            $ACLData->{ValidID} = $Self->{ValidObject}->ValidLookup( ValidID => $ACLData->{ValidID} );
 
             # print each ACL in overview table
-            $LayoutObject->Block(
+            $Self->{LayoutObject}->Block(
                 Name => 'ACLRow',
                 Data => {
                     %{$ACLData},
@@ -622,17 +644,17 @@ sub _ShowOverview {
     else {
 
         # print no data found message
-        $LayoutObject->Block(
+        $Self->{LayoutObject}->Block(
             Name => 'ACLNoDataRow',
             Data => {},
         );
     }
 
-    $Output .= $LayoutObject->Output(
+    $Output .= $Self->{LayoutObject}->Output(
         TemplateFile => 'AdminACL',
         Data         => \%Param,
     );
-    $Output .= $LayoutObject->Footer();
+    $Output .= $Self->{LayoutObject}->Footer();
 
     return $Output;
 }
@@ -640,15 +662,12 @@ sub _ShowOverview {
 sub _ShowEdit {
     my ( $Self, %Param ) = @_;
 
-    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
-
     # get ACL information
     my $ACLData = $Param{ACLData} || {};
 
-    # decide whether to show delete button
+    # decide wether to show delete button
     if ( $Param{Action} eq 'Edit' && $ACLData && $ACLData->{ValidID} ne '1' ) {
-        $LayoutObject->Block(
+        $Self->{LayoutObject}->Block(
             Name => 'ACLDeleteAction',
             Data => {
                 %{$ACLData},
@@ -657,107 +676,93 @@ sub _ShowEdit {
     }
 
     # get valid list
-    my %ValidList = $Kernel::OM->Get('Kernel::System::Valid')->ValidList();
+    my %ValidList = $Self->{ValidObject}->ValidList();
 
-    $Param{ValidOption} = $LayoutObject->BuildSelection(
+    $Param{ValidOption} = $Self->{LayoutObject}->BuildSelection(
         Data       => \%ValidList,
         Name       => 'ValidID',
         SelectedID => $ACLData->{ValidID} || $ValidList{valid},
-        Class      => 'Modernize Validate_Required ' . ( $Param{Errors}->{'ValidIDInvalid'} || '' ),
+        Class      => 'Validate_Required ' . ( $Param{Errors}->{'ValidIDInvalid'} || '' ),
     );
 
-    my $ACLKeysLevel1Match = $ConfigObject->Get('ACLKeysLevel1Match') || {};
-    $Param{ACLKeysLevel1Match} = $LayoutObject->BuildSelection(
+    my $ACLKeysLevel1Match = $Self->{ConfigObject}->Get('ACLKeysLevel1Match') || {};
+    $Param{ACLKeysLevel1Match} = $Self->{LayoutObject}->BuildSelection(
         Data         => $ACLKeysLevel1Match,
         Name         => 'ItemAdd',
-        Class        => 'Modernize ItemAdd ItemAddLevel1',
+        Class        => 'ItemAdd ItemAddLevel1',
         ID           => 'ItemAddLevel1Match',
         TreeView     => 1,
         PossibleNone => 1,
         Translation  => 0,
     );
 
-    my $ACLKeysLevel1Change = $ConfigObject->Get('ACLKeysLevel1Change') || {};
-    $Param{ACLKeysLevel1Change} = $LayoutObject->BuildSelection(
+    my $ACLKeysLevel1Change = $Self->{ConfigObject}->Get('ACLKeysLevel1Change') || {};
+    $Param{ACLKeysLevel1Change} = $Self->{LayoutObject}->BuildSelection(
         Data         => $ACLKeysLevel1Change,
         Name         => 'ItemAdd',
-        Class        => 'Modernize ItemAdd ItemAddLevel1',
+        Class        => 'ItemAdd ItemAddLevel1',
         ID           => 'ItemAddLevel1Change',
         TreeView     => 1,
         PossibleNone => 1,
         Translation  => 0,
     );
 
-    my $ACLKeysLevel2Possible = $ConfigObject->Get('ACLKeysLevel2::Possible') || {};
-    $Param{ACLKeysLevel2Possible} = $LayoutObject->BuildSelection(
+    my $ACLKeysLevel2Possible = $Self->{ConfigObject}->Get('ACLKeysLevel2::Possible') || {};
+    $Param{ACLKeysLevel2Possible} = $Self->{LayoutObject}->BuildSelection(
         Data         => $ACLKeysLevel2Possible,
         Name         => 'ItemAdd',
         ID           => 'Possible',
-        Class        => 'Modernize ItemAdd LevelToBeAdded',
+        Class        => 'ItemAdd LevelToBeAdded',
         Translation  => 0,
         PossibleNone => 1,
     );
 
-    my $ACLKeysLevel2PossibleAdd = $ConfigObject->Get('ACLKeysLevel2::PossibleAdd') || {};
-    $Param{ACLKeysLevel2PossibleAdd} = $LayoutObject->BuildSelection(
-        Data         => $ACLKeysLevel2PossibleAdd,
-        Name         => 'ItemAdd',
-        ID           => 'PossibleAdd',
-        Class        => 'Modernize ItemAdd LevelToBeAdded',
-        Translation  => 0,
-        PossibleNone => 1,
-    );
-
-    my $ACLKeysLevel2PossibleNot = $ConfigObject->Get('ACLKeysLevel2::PossibleNot') || {};
-    $Param{ACLKeysLevel2PossibleNot} = $LayoutObject->BuildSelection(
+    my $ACLKeysLevel2PossibleNot = $Self->{ConfigObject}->Get('ACLKeysLevel2::PossibleNot') || {};
+    $Param{ACLKeysLevel2PossibleNot} = $Self->{LayoutObject}->BuildSelection(
         Data         => $ACLKeysLevel2PossibleNot,
         Name         => 'ItemAdd',
         ID           => 'PossibleNot',
-        Class        => 'Modernize ItemAdd LevelToBeAdded',
+        Class        => 'ItemAdd LevelToBeAdded',
         Translation  => 0,
         PossibleNone => 1,
     );
 
-    my $ACLKeysLevel2Properties = $ConfigObject->Get('ACLKeysLevel2::Properties') || {};
-    $Param{ACLKeysLevel2Properties} = $LayoutObject->BuildSelection(
+    my $ACLKeysLevel2Properties = $Self->{ConfigObject}->Get('ACLKeysLevel2::Properties') || {};
+    $Param{ACLKeysLevel2Properties} = $Self->{LayoutObject}->BuildSelection(
         Data         => $ACLKeysLevel2Properties,
         Name         => 'ItemAdd',
         ID           => 'Properties',
-        Class        => 'Modernize ItemAdd LevelToBeAdded',
+        Class        => 'ItemAdd LevelToBeAdded',
         Translation  => 0,
         PossibleNone => 1,
     );
 
-    my $ACLKeysLevel2PropertiesDatabase = $ConfigObject->Get('ACLKeysLevel2::PropertiesDatabase') || {};
-    $Param{ACLKeysLevel2PropertiesDatabase} = $LayoutObject->BuildSelection(
+    my $ACLKeysLevel2PropertiesDatabase = $Self->{ConfigObject}->Get('ACLKeysLevel2::PropertiesDatabase') || {};
+    $Param{ACLKeysLevel2PropertiesDatabase} = $Self->{LayoutObject}->BuildSelection(
         Data         => $ACLKeysLevel2PropertiesDatabase,
         Name         => 'ItemAdd',
         ID           => 'PropertiesDatabase',
-        Class        => 'Modernize ItemAdd LevelToBeAdded',
+        Class        => 'ItemAdd LevelToBeAdded',
         Translation  => 0,
         PossibleNone => 1,
     );
 
-    $Param{ACLKeysLevel4Prefixes} = $LayoutObject->BuildSelection(
+    $Param{ACLKeysLevel4Prefixes} = $Self->{LayoutObject}->BuildSelection(
         Data => {
-            ''            => Translatable('Exact match'),
-            '[Not]'       => Translatable('Negated exact match'),
-            '[RegExp]'    => Translatable('Regular expression'),
-            '[regexp]'    => Translatable('Regular expression (ignore case)'),
-            '[NotRegExp]' => Translatable('Negated regular expression'),
-            '[Notregexp]' => Translatable('Negated regular expression (ignore case)'),
+            ''         => 'Standard',
+            '[RegExp]' => 'Regex',
+            '[regexp]' => 'Regex (ignore case)',
         },
         Name           => 'ItemPrefix',
         Class          => 'ItemPrefix',
         ID             => 'Prefixes',
         Sort           => 'IndividualKey',
-        SortIndividual => [ '', '[Not]', '[RegExp]', '[regexp]', '[NotRegExp]', '[Notregexp]' ],
+        SortIndividual => [ '', '[RegExp]', '[regexp]' ],
         Translation    => 0,
-        AutoComplete   => 'off',
     );
 
     # get list of all possible dynamic fields
-    my $DynamicFieldList = $Kernel::OM->Get('Kernel::System::DynamicField')->DynamicFieldList(
+    my $DynamicFieldList = $Self->{DynamicFieldObject}->DynamicFieldList(
         ObjectType => 'Ticket',
         ResultType => 'HASH',
     );
@@ -766,10 +771,10 @@ sub _ShowEdit {
     for my $DynamicFieldName ( sort keys %DynamicFieldNames ) {
         $DynamicFields{ 'DynamicField_' . $DynamicFieldName } = $DynamicFieldName;
     }
-    $Param{ACLKeysLevel3DynamicFields} = $LayoutObject->BuildSelection(
+    $Param{ACLKeysLevel3DynamicFields} = $Self->{LayoutObject}->BuildSelection(
         Data         => \%DynamicFields,
         Name         => 'NewDataKeyDropdown',
-        Class        => 'Modernize NewDataKeyDropdown',
+        Class        => 'NewDataKeyDropdown',
         ID           => 'DynamicField',
         Translation  => 0,
         PossibleNone => 1,
@@ -777,56 +782,38 @@ sub _ShowEdit {
 
     # get list of all possible actions
     my @PossibleActionsList;
-    my $ACLKeysLevel3Actions = $ConfigObject->Get('ACLKeysLevel3::Actions') || [];
+    my $ACLKeysLevel3Actions = $Self->{ConfigObject}->Get('ACLKeysLevel3::Actions') || [];
 
     for my $Key ( sort keys %{$ACLKeysLevel3Actions} ) {
         push @PossibleActionsList, @{ $ACLKeysLevel3Actions->{$Key} };
     }
 
-    $Param{ACLKeysLevel3Actions} = $LayoutObject->BuildSelection(
+    $Param{ACLKeysLevel3Actions} = $Self->{LayoutObject}->BuildSelection(
         Data         => \@PossibleActionsList,
         Name         => 'NewDataKeyDropdown',
-        Class        => 'Modernize NewDataKeyDropdown Boolean',
+        Class        => 'NewDataKeyDropdown Boolean',
         ID           => 'Action',
         Translation  => 0,
         PossibleNone => 1,
     );
 
-    $Param{PossibleActionsList} = \@PossibleActionsList;
-
     if ( defined $ACLData->{StopAfterMatch} && $ACLData->{StopAfterMatch} == 1 ) {
         $Param{Checked} = 'checked="checked"';
     }
 
-    my $Output = $LayoutObject->Header();
-    $Output .= $LayoutObject->NavigationBar();
+    my $Output = $Self->{LayoutObject}->Header();
+    $Output .= $Self->{LayoutObject}->NavigationBar();
 
     # show notifications if any
     if ( $Param{NotifyData} ) {
         for my $Notification ( @{ $Param{NotifyData} } ) {
-            $Output .= $LayoutObject->Notify(
+            $Output .= $Self->{LayoutObject}->Notify(
                 %{$Notification},
             );
         }
     }
 
-    # create data for JS
-    my @ACLEditPossibleActionsList;
-    for my $Item (@PossibleActionsList) {
-        my %ACLEdit = (
-            label => $Item,
-            value => $Item
-        );
-        push @ACLEditPossibleActionsList, \%ACLEdit;
-    }
-
-    # set ACL data
-    $LayoutObject->AddJSData(
-        Key   => 'PossibleActionsList',
-        Value => \@ACLEditPossibleActionsList,
-    );
-
-    $Output .= $LayoutObject->Output(
+    $Output .= $Self->{LayoutObject}->Output(
         TemplateFile => "AdminACL$Param{Action}",
         Data         => {
             %Param,
@@ -834,7 +821,7 @@ sub _ShowEdit {
         },
     );
 
-    $Output .= $LayoutObject->Footer();
+    $Output .= $Self->{LayoutObject}->Footer();
 
     return $Output;
 }
@@ -842,7 +829,6 @@ sub _ShowEdit {
 sub _GetParams {
     my ( $Self, %Param ) = @_;
 
-    my $JSONObject = $Kernel::OM->Get('Kernel::System::JSON');
     my $GetParam;
 
     # get parameters from web browser
@@ -850,12 +836,11 @@ sub _GetParams {
         qw( Name EntityID Comment Description StopAfterMatch ValidID ConfigMatch ConfigChange )
         )
     {
-        $GetParam->{$ParamName} = $Kernel::OM->Get('Kernel::System::Web::Request')->GetParam( Param => $ParamName )
-            || '';
+        $GetParam->{$ParamName} = $Self->{ParamObject}->GetParam( Param => $ParamName ) || '';
     }
 
     if ( $GetParam->{ConfigMatch} ) {
-        $GetParam->{ConfigMatch} = $JSONObject->Decode(
+        $GetParam->{ConfigMatch} = $Self->{JSONObject}->Decode(
             Data => $GetParam->{ConfigMatch},
         );
         if ( !IsHashRefWithData( $GetParam->{ConfigMatch} ) ) {
@@ -864,7 +849,7 @@ sub _GetParams {
     }
 
     if ( $GetParam->{ConfigChange} ) {
-        $GetParam->{ConfigChange} = $JSONObject->Decode(
+        $GetParam->{ConfigChange} = $Self->{JSONObject}->Decode(
             Data => $GetParam->{ConfigChange},
         );
         if ( !IsHashRefWithData( $GetParam->{ConfigChange} ) ) {
@@ -879,7 +864,7 @@ sub _CheckACLDelete {
     my ( $Self, %Param ) = @_;
 
     # get ACL data
-    my $ACLData = $Kernel::OM->Get('Kernel::System::ACL::DB::ACL')->ACLGet(
+    my $ACLData = $Self->{ACLObject}->ACLGet(
         ID     => $Param{ID},
         UserID => $Self->{UserID},
     );
