@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AdminDynamicFieldDateTime.pm - provides a dynamic fields Date Time config view for admins
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: AdminDynamicFieldDateTime.pm,v 1.23 2012/11/20 14:37:03 mh Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -19,9 +17,6 @@ use Kernel::System::Valid;
 use Kernel::System::CheckItem;
 use Kernel::System::DynamicField;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.23 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -43,7 +38,7 @@ sub new {
     $Self->{ObjectTypeConfig} = $Self->{ConfigObject}->Get('DynamicFields::ObjectType');
 
     # get the fields config
-    $Self->{FieldTypeConfig} = $Self->{ConfigObject}->Get('DynamicFields::Backend') || {};
+    $Self->{FieldTypeConfig} = $Self->{ConfigObject}->Get('DynamicFields::Driver') || {};
 
     return $Self;
 }
@@ -127,7 +122,7 @@ sub _AddAction {
     if ( $GetParam{Name} ) {
 
         # check if name is alphanumeric
-        if ( $GetParam{Name} !~ m{\A ( ?: [a-zA-Z] | \d )+ \z}xms ) {
+        if ( $GetParam{Name} !~ m{\A (?: [a-zA-Z] | \d )+ \z}xms ) {
 
             # add server error error class
             $Errors{NameServerError} = 'ServerError';
@@ -156,7 +151,7 @@ sub _AddAction {
     if ( $GetParam{FieldOrder} ) {
 
         # check if field order is numeric and positive
-        if ( $GetParam{FieldOrder} !~ m{\A ( ?: \d )+ \z}xms ) {
+        if ( $GetParam{FieldOrder} !~ m{\A (?: \d )+ \z}xms ) {
 
             # add server error error class
             $Errors{FieldOrderServerError}        = 'ServerError';
@@ -325,7 +320,7 @@ sub _ChangeAction {
     if ( $GetParam{Name} ) {
 
         # check if name is lowercase
-        if ( $GetParam{Name} !~ m{\A ( ?: [a-zA-Z] | \d )+ \z}xms ) {
+        if ( $GetParam{Name} !~ m{\A (?: [a-zA-Z] | \d )+ \z}xms ) {
 
             # add server error error class
             $Errors{NameServerError} = 'ServerError';
@@ -371,7 +366,7 @@ sub _ChangeAction {
     if ( $GetParam{FieldOrder} ) {
 
         # check if field order is numeric and positive
-        if ( $GetParam{FieldOrder} !~ m{\A ( ?: \d )+ \z}xms ) {
+        if ( $GetParam{FieldOrder} !~ m{\A (?: \d )+ \z}xms ) {
 
             # add server error error class
             $Errors{FieldOrderServerError}        = 'ServerError';
@@ -392,15 +387,15 @@ sub _ChangeAction {
         }
     }
 
-    # accept negative numbers for YearsInFuture and YearsInPast but convert them to possitive
+    # accept negative numbers for YearsInFuture and YearsInPast but convert them to positive
     # before store
     for my $DateConfigParam (qw(YearsInFuture YearsInPast)) {
 
-        # check if numeric values has the '-' sing, capture only the numbers without the sing in
+        # check if numeric values has the '-' sign, capture only the numbers without the sign in
         # $1
         if ( $GetParam{$DateConfigParam} =~ m{\A - ([\d]+) \Z}xms ) {
 
-            # set the parameter number without the '-' sing
+            # set the parameter number without the '-' sign
             $GetParam{$DateConfigParam} = $1;
         }
     }
@@ -419,7 +414,7 @@ sub _ChangeAction {
         );
     }
 
-    # return to change screen if errors
+    # return to change screen if errors occured
     if (%Errors) {
         return $Self->_ShowScreen(
             %Param,
@@ -484,8 +479,10 @@ sub _ShowScreen {
 
     # get the list of order numbers (is already sorted).
     my @DynamicfieldOrderList;
+    my %DynamicfieldNamesList;
     for my $Dynamicfield ( @{$DynamicFieldList} ) {
         push @DynamicfieldOrderList, $Dynamicfield->{FieldOrder};
+        $DynamicfieldNamesList{ $Dynamicfield->{FieldOrder} } = $Dynamicfield->{Label};
     }
 
     # when adding we need to create an extra order number for the new field
@@ -499,13 +496,26 @@ sub _ShowScreen {
         push @DynamicfieldOrderList, $LastOrderNumber;
     }
 
-    my $DynamicFieldOrderSrtg = $Self->{LayoutObject}->BuildSelection(
-        Data          => \@DynamicfieldOrderList,
+    # show the names of the other fields to ease ordering
+    my %OrderNamesList;
+    my $CurrentlyText = $Self->{LayoutObject}->{LanguageObject}->Get('Currently') . ': ';
+    for my $OrderNumber ( sort @DynamicfieldOrderList ) {
+        $OrderNamesList{$OrderNumber} = $OrderNumber;
+        if ( $DynamicfieldNamesList{$OrderNumber} && $OrderNumber ne $Param{FieldOrder} ) {
+            $OrderNamesList{$OrderNumber} = $OrderNumber . ' - '
+                . $CurrentlyText
+                . $DynamicfieldNamesList{$OrderNumber}
+        }
+    }
+
+    my $DynamicFieldOrderStrg = $Self->{LayoutObject}->BuildSelection(
+        Data          => \%OrderNamesList,
         Name          => 'FieldOrder',
         SelectedValue => $Param{FieldOrder} || 1,
         PossibleNone  => 0,
         Translation   => 0,
-        Class         => 'W50pc Validate_Number',
+        Sort          => 'NumericKey',
+        Class         => 'W75pc Validate_Number',
     );
 
     my %ValidList = $Self->{ValidObject}->ValidList();
@@ -571,7 +581,7 @@ sub _ShowScreen {
         Data         => {
             %Param,
             ValidityStrg          => $ValidityStrg,
-            DynamicFieldOrderSrtg => $DynamicFieldOrderSrtg,
+            DynamicFieldOrderStrg => $DynamicFieldOrderStrg,
             YearsPeriodStrg       => $YearsPeriodStrg,
             ClassYearsPeriod      => $ClassYearsPeriod,
             DefaultValue          => $DefaultValue,
