@@ -1,6 +1,6 @@
 # --
 # Kernel/Modules/AdminPostMasterFilter.pm - to add/update/delete filters
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -45,6 +45,7 @@ sub Run {
     for my $Number ( 1 .. 12 ) {
         $GetParam{"MatchHeader$Number"} = $Self->{ParamObject}->GetParam( Param => "MatchHeader$Number" );
         $GetParam{"MatchValue$Number"}  = $Self->{ParamObject}->GetParam( Param => "MatchValue$Number" );
+        $GetParam{"MatchNot$Number"}    = $Self->{ParamObject}->GetParam( Param => "MatchNot$Number" );
         $GetParam{"SetHeader$Number"}   = $Self->{ParamObject}->GetParam( Param => "SetHeader$Number" );
         $GetParam{"SetValue$Number"}    = $Self->{ParamObject}->GetParam( Param => "SetValue$Number" );
     }
@@ -94,10 +95,14 @@ sub Run {
 
         my %Match = ();
         my %Set   = ();
+        my %Not;
+
         for my $Number ( 1 .. 12 ) {
             if ( $GetParam{"MatchHeader$Number"} && $GetParam{"MatchValue$Number"} ) {
                 $Match{ $GetParam{"MatchHeader$Number"} } = $GetParam{"MatchValue$Number"};
+                $Not{ $GetParam{"MatchHeader$Number"} }   = $GetParam{"MatchNot$Number"};
             }
+
             if ( $GetParam{"SetHeader$Number"} && $GetParam{"SetValue$Number"} ) {
                 $Set{ $GetParam{"SetHeader$Number"} } = $GetParam{"SetValue$Number"};
             }
@@ -148,6 +153,7 @@ sub Run {
                     Set            => \%Set,
                     Match          => \%Match,
                     StopAfterMatch => $StopAfterMatch,
+                    Not            => \%Not,
                 },
             );
         }
@@ -157,6 +163,7 @@ sub Run {
             Match          => \%Match,
             Set            => \%Set,
             StopAfterMatch => $StopAfterMatch,
+            Not            => \%Not,
         );
         return $Self->{LayoutObject}->Redirect( OP => "Action=$Self->{Action}" );
     }
@@ -217,6 +224,7 @@ sub _MaskUpdate {
                 $Counter++;
                 $Data{"MatchValue$Counter"}  = $Data{Match}->{$MatchKey};
                 $Data{"MatchHeader$Counter"} = $MatchKey;
+                $Data{"MatchNot$Counter"}    = $Data{Not}->{$MatchKey} ? ' checked="checked"' : '';
             }
         }
     }
