@@ -164,8 +164,7 @@ sub Run {
         );
 
         my %UploadStuff = $Self->{ParamObject}->GetUploadAll(
-            Param  => 'FileUpload',
-            Source => 'string',
+            Param => 'FileUpload',
         );
 
         my %Errors;
@@ -234,8 +233,7 @@ sub Run {
             Value     => '',
         );
         my %UploadStuff = $Self->{ParamObject}->GetUploadAll(
-            Param  => 'FileUpload',
-            Source => 'string',
+            Param => 'FileUpload',
         );
 
         # check needed data
@@ -655,6 +653,9 @@ sub _Overview {
     $Self->{LayoutObject}->Block(
         Name => 'SMIMEFilter',
     );
+    $Self->{LayoutObject}->Block(
+        Name => 'OverviewHint',
+    );
 
     return $Output;
 }
