@@ -89,13 +89,24 @@ sub Run {
         if ( !$Self->{ConfigObject}->Get('SessionUseCookieAfterBrowserClose') ) {
             $Expires = '';
         }
+
+        my $SecureAttribute;
+        if ( $Self->{ConfigObject}->Get('HttpType') eq 'https' ) {
+
+            # Restrict Cookie to HTTPS if it is used.
+            $SecureAttribute = 1;
+        }
+
         my $LayoutObject = Kernel::Output::HTML::Layout->new(
             %{$Self},
             SetCookies => {
                 SessionIDCookie => $Self->{ParamObject}->SetCookie(
-                    Key     => $Self->{ConfigObject}->Get('SessionName'),
-                    Value   => $NewSessionID,
-                    Expires => $Expires,
+                    Key      => $Self->{ConfigObject}->Get('SessionName'),
+                    Value    => $NewSessionID,
+                    Expires  => $Expires,
+                    Path     => $Self->{ConfigObject}->Get('ScriptAlias'),
+                    Secure   => scalar $SecureAttribute,
+                    HTTPOnly => 1,
                 ),
             },
             SessionID   => $NewSessionID,
@@ -172,6 +183,17 @@ sub Run {
             $Errors{ErrorType}        = $CheckItemObject->CheckErrorType();
         }
 
+        # check if a user with this login (username) already exits
+        my $UserLoginExists = $Self->{UserObject}->UserLoginExistsCheck(
+            UserLogin => $GetParam{UserLogin},
+            UserID    => $GetParam{UserID}
+        );
+
+        if ($UserLoginExists) {
+            $Errors{UserLoginExists} = 1;
+            $Errors{'UserLoginInvalid'} = 'ServerError';
+        }
+
         # if no errors occurred
         if ( !%Errors )
         {
@@ -308,7 +330,7 @@ sub Run {
         }
         $GetParam{Preferences} = $Self->{ParamObject}->GetParam( Param => 'Preferences' ) || '';
 
-        for my $Needed (qw(UserFirstname UserLastname UserLogin UserEmail ValidID UserPw)) {
+        for my $Needed (qw(UserFirstname UserLastname UserLogin UserEmail ValidID)) {
             if ( !$GetParam{$Needed} ) {
                 $Errors{ $Needed . 'Invalid' } = 'ServerError';
             }
@@ -324,6 +346,14 @@ sub Run {
             $Errors{ErrorType}        = $CheckItemObject->CheckErrorType();
         }
 
+        # check if a user with this login (username) already exits
+        my $UserLoginExists = $Self->{UserObject}->UserLoginExistsCheck( UserLogin => $GetParam{UserLogin} );
+
+        if ($UserLoginExists) {
+            $Errors{UserLoginExists} = 1;
+            $Errors{'UserLoginInvalid'} = 'ServerError';
+        }
+
         # if no errors occurred
         if ( !%Errors )
         {
@@ -479,9 +509,9 @@ sub _Edit {
     else {
         $Self->{LayoutObject}->Block( Name => 'HeaderAdd' );
         $Self->{LayoutObject}->Block( Name => 'MarkerMandatory' );
-        $Param{ClassMandatory} = 'Mandatory';
-        $Param{UserPwRequired} = 'Validate_Required';
-
+        $Self->{LayoutObject}->Block(
+            Name => 'ShowPasswordHint',
+        );
     }
 
     # add the correct server error msg
@@ -500,6 +530,14 @@ sub _Edit {
         );
     }
 
+    # show appropriate messages for ServerError
+    if ( defined $Param{UserLoginExists} && $Param{UserLoginExists} == 1 ) {
+        $Self->{LayoutObject}->Block( Name => 'ExistUserLoginServerError' );
+    }
+    else {
+        $Self->{LayoutObject}->Block( Name => 'UserLoginServerError' );
+    }
+
     my @Groups = @{ $Self->{ConfigObject}->Get('PreferencesView') };
     for my $Column (@Groups) {
         my %Data        = ();
