@@ -126,11 +126,9 @@ sub Run {
                 # replace all line breaks with spaces (otherwise $Text{""} will not work correctly)
                 $StatsHash->{$StatID}->{Description} =~ s{\r?\n|\r}{ }msxg;
 
-                my $Description = $Self->{LayoutObject}->{LanguageObject}
-                    ->Get( $StatsHash->{$StatID}->{Description} );
+                my $Description = $Self->{LayoutObject}->{LanguageObject}->Get( $StatsHash->{$StatID}->{Description} );
 
-                my $Title = $Self->{LayoutObject}->{LanguageObject}
-                    ->Get( $StatsHash->{$StatID}->{Title} );
+                my $Title = $Self->{LayoutObject}->{LanguageObject}->Get( $StatsHash->{$StatID}->{Title} );
                 $Title = $Self->{LayoutObject}->{LanguageObject}->Get('Statistic') . ': ' . $Title;
 
                 $Config->{ ( $StatID + 1000 ) . '-Stats' } = {
@@ -153,8 +151,7 @@ sub Run {
                 ->{JavaScript} || []
         };
         @ModuleJS = grep { $_ !~ m/d3js/ } @ModuleJS;
-        $Self->{ConfigObject}->Get('Frontend::Module')->{AgentDashboard}->{Loader}->{JavaScript}
-            = \@ModuleJS;
+        $Self->{ConfigObject}->Get('Frontend::Module')->{AgentDashboard}->{Loader}->{JavaScript} = \@ModuleJS;
     }
 
     if ( $Self->{Action} eq 'AgentCustomerInformationCenter' ) {
@@ -163,7 +160,7 @@ sub Run {
 
         # check CustomerID presence for all subactions that need it
         if ( $Self->{Subaction} ne 'UpdatePosition' ) {
-            if ( !$Self->{CustomerID} ) {
+            if ( !$Self->{CustomerID} || $Self->{CustomerID} =~ /[*|%]/i ) {
                 my $Output = $Self->{LayoutObject}->Header();
                 $Output .= $Self->{LayoutObject}->NavigationBar();
                 $Output .= $Self->{LayoutObject}->Output(
@@ -258,7 +255,11 @@ sub Run {
         }
 
         # deliver new content page
-        my %ElementReload = $Self->_Element( Name => $Name, Configs => $Config, AJAX => 1 );
+        my %ElementReload = $Self->_Element(
+            Name    => $Name,
+            Configs => $Config,
+            AJAX    => 1
+        );
         if ( !%ElementReload ) {
             $Self->{LayoutObject}->FatalError(
                 Message => "Can't get element data of $Name!",
@@ -370,8 +371,7 @@ sub Run {
             qw(Owner Responsible State Queue Priority Type Lock Service SLA CustomerID CustomerUserID)
             )
         {
-            my $FilterValue
-                = $Self->{ParamObject}->GetParam( Param => 'ColumnFilter' . $ColumnName . $Name )
+            my $FilterValue = $Self->{ParamObject}->GetParam( Param => 'ColumnFilter' . $ColumnName . $Name )
                 || '';
             next COLUMNNAME if $FilterValue eq '';
 
@@ -400,10 +400,9 @@ sub Run {
             next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
             next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
 
-            my $FilterValue
-                = $Self->{ParamObject}->GetParam(
+            my $FilterValue = $Self->{ParamObject}->GetParam(
                 Param => 'ColumnFilterDynamicField_' . $DynamicFieldConfig->{Name} . $Name
-                );
+            );
 
             next DYNAMICFIELD if !defined $FilterValue;
             next DYNAMICFIELD if $FilterValue eq '';
@@ -411,10 +410,8 @@ sub Run {
             $ColumnFilter{ 'DynamicField_' . $DynamicFieldConfig->{Name} } = {
                 Equals => $FilterValue,
             };
-            $GetColumnFilter{ 'DynamicField_' . $DynamicFieldConfig->{Name} . $Name }
-                = $FilterValue;
-            $GetColumnFilterSelect{ 'DynamicField_' . $DynamicFieldConfig->{Name} }
-                = $FilterValue;
+            $GetColumnFilter{ 'DynamicField_' . $DynamicFieldConfig->{Name} . $Name } = $FilterValue;
+            $GetColumnFilterSelect{ 'DynamicField_' . $DynamicFieldConfig->{Name} } = $FilterValue;
         }
 
         my $SortBy  = $Self->{ParamObject}->GetParam( Param => 'SortBy' );
@@ -498,8 +495,7 @@ sub Run {
         );
 
         if ( $CustomerCompanyData{CustomerCompanyName} ) {
-            $ContentBlockData{CustomerIDTitle}
-                = "$CustomerCompanyData{CustomerCompanyName} ($Self->{CustomerID})";
+            $ContentBlockData{CustomerIDTitle} = "$CustomerCompanyData{CustomerCompanyName} ($Self->{CustomerID})";
         }
     }
 
@@ -669,7 +665,7 @@ sub Run {
     }
 
     # add translations for the allocation lists for regular columns
-    my $Columns = $Self->{ConfigObject}->Get('DefaultOverviewColumns') || {};
+    my $Columns = $Self->{Config}->{DefaultColumns} || $Self->{ConfigObject}->Get('DefaultOverviewColumns') || {};
     if ( $Columns && IsHashRefWithData($Columns) ) {
 
         COLUMN:
@@ -761,6 +757,14 @@ sub _Element {
         return if !$PermissionOK;
     }
 
+    # create CustomerUserObject is it was not created before
+    if ( !$Self->{CustomerUserObject} ) {
+        $Self->{CustomerUserObject} = Kernel::System::CustomerUser->new(
+            %{$Self},
+            DBObject => $Self->{SlaveDBObject},
+        );
+    }
+
     # load backends
     my $Module = $Configs->{$Name}->{Module};
     return if !$Self->{MainObject}->Require($Module);
@@ -817,8 +821,7 @@ sub _Element {
     my $Content;
     my $CacheKey = $Config{CacheKey};
     if ( !$CacheKey ) {
-        $CacheKey
-            = $Name . '-'
+        $CacheKey = $Name . '-'
             . ( $Self->{CustomerID} || '' ) . '-'
             . $Self->{LayoutObject}->{UserLanguage};
     }
@@ -834,7 +837,7 @@ sub _Element {
     if ( !defined $Content || $SortBy ) {
         $CacheUsed = 0;
         $Content   = $Object->Run(
-            AJAX => $Param{AJAX},
+            AJAX       => $Param{AJAX},
             CustomerID => $Self->{CustomerID} || '',
         );
     }
