@@ -1,6 +1,6 @@
 # --
 # Kernel/Output/HTML/ArticleCheckSMIME.pm
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -31,7 +31,10 @@ sub new {
             $Self->{$_} = $Param{$_};
         }
         else {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
         }
     }
     return $Self;
@@ -49,6 +52,7 @@ sub Check {
     # check if article is an email
     return if $Param{Article}->{ArticleType} !~ /email/i;
 
+    my $StoreDecryptedData = $Self->{ConfigObject}->Get('SMIME::StoreDecryptedData');
     $Self->{CryptObject} = Kernel::System::Crypt->new( %{$Self}, CryptType => 'SMIME' );
 
     # check inline smime
@@ -87,7 +91,10 @@ sub Check {
             push( @Email, $Line . "\n" );
         }
 
-        my $ParserObject = Kernel::System::EmailParser->new( %{$Self}, Email => \@Email, );
+        my $ParserObject = Kernel::System::EmailParser->new(
+            %{$Self},
+            Email => \@Email,
+        );
 
         use MIME::Parser;
         my $Parser = MIME::Parser->new();
@@ -142,8 +149,9 @@ sub Check {
 
                 # filter email addresses avoiding repeated and save on hash to search
                 for my $EmailAddress (@EmailAddressOnField) {
-                    my $CleanEmailAddress
-                        = $ParserObject->GetEmailAddress( Email => $EmailAddress, );
+                    my $CleanEmailAddress = $ParserObject->GetEmailAddress(
+                        Email => $EmailAddress,
+                    );
                     $EmailsToSearch{$CleanEmailAddress} = '1';
                 }
             }
@@ -152,8 +160,9 @@ sub Check {
             # extract every resulting cert and put it into an hash of hashes avoiding repeated
             my %PrivateKeys;
             for my $EmailAddress ( sort keys %EmailsToSearch ) {
-                my @PrivateKeysResult
-                    = $Self->{CryptObject}->PrivateSearch( Search => $EmailAddress, );
+                my @PrivateKeysResult = $Self->{CryptObject}->PrivateSearch(
+                    Search => $EmailAddress,
+                );
                 for my $Cert (@PrivateKeysResult) {
                     $PrivateKeys{ $Cert->{Filename} } = $Cert;
                 }
@@ -190,7 +199,7 @@ sub Check {
                 push(
                     @Return,
                     {
-                        Key => 'Crypted',
+                        Key   => 'Crypted',
                         Value => $Decrypt{Message} || 'Successful decryption',
                         %Decrypt,
                     }
@@ -200,12 +209,14 @@ sub Check {
                 my $EmailContent = $Decrypt{Data};
 
                 # now check if the data contains a signature too
-                %SignCheck = $Self->{CryptObject}->Verify( Message => $Decrypt{Data}, );
+                %SignCheck = $Self->{CryptObject}->Verify(
+                    Message => $Decrypt{Data},
+                );
 
                 if ( $SignCheck{SignatureFound} ) {
 
-                  # If the signature was verified well, use the stripped content to store the email.
-                  #   Now it contains only the email without other SMIME generated data.
+                    # If the signature was verified well, use the stripped content to store the email.
+                    #   Now it contains only the email without other SMIME generated data.
                     $EmailContent = $SignCheck{Content} if $SignCheck{Successful};
 
                     push(
@@ -219,8 +230,7 @@ sub Check {
                 }
 
                 # parse the decrypted email body
-                my $ParserObject
-                    = Kernel::System::EmailParser->new( %{$Self}, Email => $EmailContent );
+                my $ParserObject = Kernel::System::EmailParser->new( %{$Self}, Email => $EmailContent );
                 my $Body = $ParserObject->GetMessageBody();
 
                 # from RFC 3850
@@ -272,30 +282,31 @@ sub Check {
                         . ", but sender address $OrigSender: does not match certificate address!";
                 }
 
-                # updated article body
-                $Self->{TicketObject}->ArticleUpdate(
-                    TicketID  => $Param{Article}->{TicketID},
-                    ArticleID => $Self->{ArticleID},
-                    Key       => 'Body',
-                    Value     => $Body,
-                    UserID    => $Self->{UserID},
-                );
+                if ($StoreDecryptedData) {
 
-                # delete crypted attachments
-                $Self->{TicketObject}->ArticleDeleteAttachment(
-                    ArticleID => $Self->{ArticleID},
-                    UserID    => $Self->{UserID},
-                );
-
-                # write attachments to the storage
-                for my $Attachment ( $ParserObject->GetAttachments() ) {
-                    $Self->{TicketObject}->ArticleWriteAttachment(
-                        Content     => $Attachment->{Content},
-                        Filename    => $Attachment->{Filename},
-                        ContentType => $Attachment->{ContentType},
-                        ArticleID   => $Self->{ArticleID},
-                        UserID      => $Self->{UserID},
+                    # updated article body
+                    $Self->{TicketObject}->ArticleUpdate(
+                        TicketID  => $Param{Article}->{TicketID},
+                        ArticleID => $Self->{ArticleID},
+                        Key       => 'Body',
+                        Value     => $Body,
+                        UserID    => $Self->{UserID},
                     );
+
+                    # delete crypted attachments
+                    $Self->{TicketObject}->ArticleDeleteAttachment(
+                        ArticleID => $Self->{ArticleID},
+                        UserID    => $Self->{UserID},
+                    );
+
+                    # write attachments to the storage
+                    for my $Attachment ( $ParserObject->GetAttachments() ) {
+                        $Self->{TicketObject}->ArticleWriteAttachment(
+                            %{$Attachment},
+                            ArticleID => $Self->{ArticleID},
+                            UserID    => $Self->{UserID},
+                        );
+                    }
                 }
 
                 return @Return;
@@ -333,7 +344,9 @@ sub Check {
             }
 
             # check sign and get clear content
-            %SignCheck = $Self->{CryptObject}->Verify( Message => $Message, );
+            %SignCheck = $Self->{CryptObject}->Verify(
+                Message => $Message,
+            );
 
             # parse and update clear content
             if ( %SignCheck && $SignCheck{Successful} && $SignCheck{Content} ) {
@@ -343,7 +356,10 @@ sub Check {
                 for (@Lines) {
                     push( @Email, $_ . "\n" );
                 }
-                my $ParserObject = Kernel::System::EmailParser->new( %{$Self}, Email => \@Email, );
+                my $ParserObject = Kernel::System::EmailParser->new(
+                    %{$Self},
+                    Email => \@Email,
+                );
                 my $Body = $ParserObject->GetMessageBody();
 
                 # from RFC 3850
@@ -395,30 +411,31 @@ sub Check {
                         . ", but sender address $OrigSender: does not match certificate address!";
                 }
 
-                # updated article body
-                $Self->{TicketObject}->ArticleUpdate(
-                    TicketID  => $Param{Article}->{TicketID},
-                    ArticleID => $Self->{ArticleID},
-                    Key       => 'Body',
-                    Value     => $Body,
-                    UserID    => $Self->{UserID},
-                );
+                if ($StoreDecryptedData) {
 
-                # delete crypted attachments
-                $Self->{TicketObject}->ArticleDeleteAttachment(
-                    ArticleID => $Self->{ArticleID},
-                    UserID    => $Self->{UserID},
-                );
-
-                # write attachments to the storage
-                for my $Attachment ( $ParserObject->GetAttachments() ) {
-                    $Self->{TicketObject}->ArticleWriteAttachment(
-                        Content     => $Attachment->{Content},
-                        Filename    => $Attachment->{Filename},
-                        ContentType => $Attachment->{ContentType},
-                        ArticleID   => $Self->{ArticleID},
-                        UserID      => $Self->{UserID},
+                    # updated article body
+                    $Self->{TicketObject}->ArticleUpdate(
+                        TicketID  => $Param{Article}->{TicketID},
+                        ArticleID => $Self->{ArticleID},
+                        Key       => 'Body',
+                        Value     => $Body,
+                        UserID    => $Self->{UserID},
                     );
+
+                    # delete crypted attachments
+                    $Self->{TicketObject}->ArticleDeleteAttachment(
+                        ArticleID => $Self->{ArticleID},
+                        UserID    => $Self->{UserID},
+                    );
+
+                    # write attachments to the storage
+                    for my $Attachment ( $ParserObject->GetAttachments() ) {
+                        $Self->{TicketObject}->ArticleWriteAttachment(
+                            %{$Attachment},
+                            ArticleID => $Self->{ArticleID},
+                            UserID    => $Self->{UserID},
+                        );
+                    }
                 }
             }
 
@@ -430,6 +447,7 @@ sub Check {
                 && !$SignCheck{Content}
                 )
             {
+
                 # return result
                 push(
                     @Return,
