@@ -29,7 +29,9 @@ sub new {
         die "Got no $_!" if ( !$Self->{$_} );
     }
 
-    $Self->{CustomerUserObject} = Kernel::System::CustomerUser->new( %{$Self} );
+    # use customer user object if it comes in the params
+    $Self->{CustomerUserObject} = $Param{CustomerUserObject}
+        // Kernel::System::CustomerUser->new( %{$Self} );
 
     # get current filter
     my $Name = $Self->{ParamObject}->GetParam( Param => 'Name' ) || '';
@@ -86,14 +88,12 @@ sub Run {
 
     return if !$Param{CustomerID};
 
-    my $CustomerIDs
-        = { $Self->{CustomerUserObject}->CustomerSearch( CustomerID => $Param{CustomerID} ) };
+    my $CustomerIDs = { $Self->{CustomerUserObject}->CustomerSearch( CustomerID => $Param{CustomerID} ) };
 
     # add page nav bar
     my $Total = scalar keys %{$CustomerIDs};
 
-    my $LinkPage
-        = 'Subaction=Element;Name='
+    my $LinkPage = 'Subaction=Element;Name='
         . $Self->{Name} . ';'
         . 'CustomerID='
         . $Self->{LayoutObject}->LinkEncode( $Param{CustomerID} ) . ';';
@@ -165,8 +165,33 @@ sub Run {
         );
     }
 
-    my @CustomerKeys
-        = sort { lc( $CustomerIDs->{$a} ) cmp lc( $CustomerIDs->{$b} ) } keys %{$CustomerIDs};
+    # get the permission for the phone ticket creation
+    my $NewAgentTicketPhonePermission = $Self->{LayoutObject}->Permission(
+        Action => 'AgentTicketPhone',
+        Type   => 'rw',
+    );
+
+    # check the permission for the phone ticket creation
+    if ($NewAgentTicketPhonePermission) {
+        $Self->{LayoutObject}->Block(
+            Name => 'OverviewResultNewAgentTicketPhone',
+        );
+    }
+
+    # get the permission for the email ticket creation
+    my $NewAgentTicketEmailPermission = $Self->{LayoutObject}->Permission(
+        Action => 'AgentTicketEmail',
+        Type   => 'rw',
+    );
+
+    # check the permission for the email ticket creation
+    if ($NewAgentTicketEmailPermission) {
+        $Self->{LayoutObject}->Block(
+            Name => 'OverviewResultNewAgentTicketEmail',
+        );
+    }
+
+    my @CustomerKeys = sort { lc( $CustomerIDs->{$a} ) cmp lc( $CustomerIDs->{$b} ) } keys %{$CustomerIDs};
     @CustomerKeys = splice @CustomerKeys, $Self->{StartHit} - 1, $Self->{PageShown};
 
     for my $CustomerKey (@CustomerKeys) {
@@ -241,6 +266,30 @@ sub Run {
             },
         );
 
+        # check the permission for the phone ticket creation
+        if ($NewAgentTicketPhonePermission) {
+            $Self->{LayoutObject}->Block(
+                Name => 'ContentLargeCustomerUserListNewAgentTicketPhone',
+                Data => {
+                    %Param,
+                    CustomerKey       => $CustomerKey,
+                    CustomerListEntry => $CustomerIDs->{$CustomerKey},
+                },
+            );
+        }
+
+        # check the permission for the email ticket creation
+        if ($NewAgentTicketEmailPermission) {
+            $Self->{LayoutObject}->Block(
+                Name => 'ContentLargeCustomerUserListNewAgentTicketEmail',
+                Data => {
+                    %Param,
+                    CustomerKey       => $CustomerKey,
+                    CustomerListEntry => $CustomerIDs->{$CustomerKey},
+                },
+            );
+        }
+
         if ( $Self->{ConfigObject}->Get('SwitchToCustomer') && $Self->{SwitchToCustomerPermission} )
         {
             $Self->{LayoutObject}->Block(
@@ -263,6 +312,24 @@ sub Run {
         );
     }
 
+    # check for refresh time
+    my $Refresh = '';
+    if ( $Self->{UserRefreshTime} ) {
+        $Refresh = 60 * $Self->{UserRefreshTime};
+        my $NameHTML = $Self->{Name};
+        $NameHTML =~ s{-}{_}xmsg;
+        $Self->{LayoutObject}->Block(
+            Name => 'ContentLargeTicketGenericRefresh',
+            Data => {
+                %{ $Self->{Config} },
+                Name        => $Self->{Name},
+                NameHTML    => $NameHTML,
+                RefreshTime => $Refresh,
+                CustomerID  => $Param{CustomerID},
+            },
+        );
+    }
+
     my $Content = $Self->{LayoutObject}->Output(
         TemplateFile => 'AgentDashboardCustomerUserList',
         Data         => {
