@@ -1,9 +1,11 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/System/CustomerAuth/HTTPBasicAuth.pm - provides the $ENV authentication
+# Authentication
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 # Note:
 #
@@ -21,11 +23,6 @@ package Kernel::System::CustomerAuth::HTTPBasicAuth;
 use strict;
 use warnings;
 
-our @ObjectDependencies = (
-    'Kernel::Config',
-    'Kernel::System::Log',
-);
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -33,6 +30,11 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
+    # check needed objects
+    for (qw(LogObject ConfigObject DBObject)) {
+        $Self->{$_} = $Param{$_} || die "No $_!";
+    }
+
     # Debug 0=off 1=on
     $Self->{Debug} = 0;
 
@@ -46,7 +48,7 @@ sub GetOption {
 
     # check needed stuff
     if ( !$Param{What} ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'error',
             Message  => "Need What!"
         );
@@ -71,7 +73,7 @@ sub Auth {
 
     # return on on user
     if ( !$User ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'notice',
             Message =>
                 "User: No \$ENV{REMOTE_USER} or \$ENV{HTTP_REMOTE_USER} !(REMOTE_ADDR: $RemoteAddr).",
@@ -79,11 +81,8 @@ sub Auth {
         return;
     }
 
-    # get config object
-    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
-
     # replace parts of login
-    my $Replace = $ConfigObject->Get(
+    my $Replace = $Self->{ConfigObject}->Get(
         'Customer::AuthModule::HTTPBasicAuth::Replace' . $Self->{Count},
     );
     if ($Replace) {
@@ -91,7 +90,7 @@ sub Auth {
     }
 
     # regexp on login
-    my $ReplaceRegExp = $ConfigObject->Get(
+    my $ReplaceRegExp = $Self->{ConfigObject}->Get(
         'Customer::AuthModule::HTTPBasicAuth::ReplaceRegExp' . $Self->{Count},
     );
     if ($ReplaceRegExp) {
@@ -99,11 +98,12 @@ sub Auth {
     }
 
     # log
-    $Kernel::OM->Get('Kernel::System::Log')->Log(
+    $Self->{LogObject}->Log(
         Priority => 'notice',
         Message  => "User: $User Authentication ok (REMOTE_ADDR: $RemoteAddr).",
     );
 
+    # return user
     return $User;
 }
 
