@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Kernel/System/GenericInterface/ObjectLockState.pm - backend for lock state handling
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,11 +12,6 @@ package Kernel::System::GenericInterface::ObjectLockState;
 use strict;
 use warnings;
 
-our @ObjectDependencies = (
-    'Kernel::System::DB',
-    'Kernel::System::Log',
-);
-
 =head1 NAME
 
 Kernel::System::GenericInterface::ObjectLockState - lock state backend
@@ -30,11 +26,47 @@ Kernel::System::GenericInterface::ObjectLockState - lock state backend
 
 =item new()
 
-create a debug log object. Do not use it directly, instead use:
+create an object
 
-    use Kernel::System::ObjectManager;
-    local $Kernel::OM = Kernel::System::ObjectManager->new();
-    my $ObjectLockStateObject = $Kernel::OM->Get('Kernel::System::GenericInterface::ObjectLockState');
+    use Kernel::Config;
+    use Kernel::System::Encode;
+    use Kernel::System::Log;
+    use Kernel::System::Time;
+    use Kernel::System::Main;
+    use Kernel::System::DB;
+    use Kernel::System::GenericInterface::ObjectLockState;
+
+    my $ConfigObject = Kernel::Config->new();
+    my $EncodeObject = Kernel::System::Encode->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+    );
+    my $TimeObject = Kernel::System::Time->new(
+        ConfigObject => $ConfigObject,
+        LogObject    => $LogObject,
+    );
+    my $MainObject = Kernel::System::Main->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+        LogObject    => $LogObject,
+    );
+    my $DBObject = Kernel::System::DB->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+        LogObject    => $LogObject,
+        MainObject   => $MainObject,
+    );
+    my $ObjectLockStateObject = Kernel::System::GenericInterface::ObjectLockState->new(
+        ConfigObject   => $ConfigObject,
+        LogObject      => $LogObject,
+        DBObject       => $DBObject,
+        MainObject     => $MainObject,
+        TimeObject     => $TimeObject,
+        EncodeObject   => $EncodeObject,
+    );
 
 =cut
 
@@ -45,6 +77,11 @@ sub new {
     my $Self = {};
     bless( $Self, $ObjectLockState );
 
+    # check needed objects
+    for my $Object (qw(DBObject ConfigObject LogObject MainObject EncodeObject TimeObject)) {
+        $Self->{$Object} = $Param{$Object} || die "Got no $Object!";
+    }
+
     return $Self;
 }
 
@@ -68,7 +105,7 @@ sub ObjectLockStateSet {
     # check needed stuff
     for my $Key (qw(WebserviceID ObjectType ObjectID LockState)) {
         if ( !$Param{$Key} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'error',
                 Message  => "Need $Key!"
             );
@@ -76,12 +113,9 @@ sub ObjectLockStateSet {
         }
     }
 
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
     # create new
     if ( !%{ $Self->ObjectLockStateGet(%Param) || {} } ) {
-        return if !$DBObject->Do(
+        return if !$Self->{DBObject}->Do(
             SQL => '
                 INSERT INTO gi_object_lock_state
                     (webservice_id, object_type, object_id, lock_state, lock_state_counter, create_time, change_time)
@@ -97,7 +131,7 @@ sub ObjectLockStateSet {
     }
     else {    # update existing
 
-        return if !$DBObject->Do(
+        return if !$Self->{DBObject}->Do(
             SQL => '
                 UPDATE gi_object_lock_state
                 SET lock_state = ?, lock_state_counter = ?, change_time = current_timestamp
@@ -150,7 +184,7 @@ sub ObjectLockStateGet {
     # check needed stuff
     for my $Key (qw(WebserviceID ObjectType ObjectID)) {
         if ( !$Param{$Key} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'error',
                 Message  => "Need $Key!"
             );
@@ -158,10 +192,7 @@ sub ObjectLockStateGet {
         }
     }
 
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
-    return if !$DBObject->Prepare(
+    return if !$Self->{DBObject}->Prepare(
         SQL => '
             SELECT webservice_id, object_type, object_id, lock_state, lock_state_counter, create_time, change_time
             FROM gi_object_lock_state
@@ -176,7 +207,8 @@ sub ObjectLockStateGet {
     );
 
     my %Result;
-    while ( my @Data = $DBObject->FetchrowArray() ) {
+
+    while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
 
         %Result = (
             WebserviceID     => $Data[0],
@@ -210,7 +242,7 @@ sub ObjectLockStateDelete {
     # check needed stuff
     for my $Key (qw(WebserviceID ObjectType ObjectID)) {
         if ( !$Param{$Key} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'error',
                 Message  => "Need $Key!"
             );
@@ -220,10 +252,7 @@ sub ObjectLockStateDelete {
 
     return if ( !%{ $Self->ObjectLockStateGet(%Param) || {} } );
 
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
-    return if !$DBObject->Do(
+    return if !$Self->{DBObject}->Do(
         SQL => '
             DELETE FROM gi_object_lock_state
             WHERE webservice_id = ?
@@ -255,7 +284,7 @@ sub ObjectLockStatePurge {
     # check needed stuff
     for my $Key (qw(WebserviceID)) {
         if ( !$Param{$Key} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'error',
                 Message  => "Need $Key!"
             );
@@ -263,10 +292,7 @@ sub ObjectLockStatePurge {
         }
     }
 
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
-    return if !$DBObject->Do(
+    return if !$Self->{DBObject}->Do(
         SQL => '
             DELETE FROM gi_object_lock_state
             WHERE webservice_id = ?',
@@ -311,7 +337,7 @@ sub ObjectLockStateList {
     # check needed stuff
     for my $Key (qw(ObjectType)) {
         if ( !$Param{$Key} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'error',
                 Message  => "Need $Key!"
             );
@@ -339,17 +365,14 @@ sub ObjectLockStateList {
 
     $SQL .= ' ORDER BY object_id ASC';
 
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
-    return if !$DBObject->Prepare(
+    return if !$Self->{DBObject}->Prepare(
         SQL  => $SQL,
         Bind => \@Bind,
     );
 
     my @Result;
 
-    while ( my @Data = $DBObject->FetchrowArray() ) {
+    while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
 
         push @Result, {
             WebserviceID     => $Data[0],
