@@ -12,13 +12,16 @@ package Kernel::System::Loader;
 use strict;
 use warnings;
 
-use vars qw(@ISA);
-
-use Kernel::System::CacheInternal;
-
 use CSS::Minifier qw();
 use JavaScript::Minifier qw();
 
+use Kernel::System::CacheInternal;
+## nofilter(TidyAll::Plugin::OTRS::Perl::LayoutObject)
+use Kernel::Output::HTML::Layout;
+## nofilter(TidyAll::Plugin::OTRS::Perl::ParamObject)
+use Kernel::System::Web::Request;
+use Kernel::System::Time;
+
 =head1 NAME
 
 Kernel::System::Loader - CSS/JavaScript loader backend
@@ -146,7 +149,7 @@ sub MinifyFiles {
     if ( !$Param{Type} || !$ValidTypeParams{ $Param{Type} } ) {
         $Self->{LogObject}->Log(
             Priority => 'error',
-            Message => "Need Type! Must be one of '" . join( ', ', keys %ValidTypeParams ) . "'."
+            Message  => "Need Type! Must be one of '" . join( ', ', keys %ValidTypeParams ) . "'."
         );
         return;
     }
@@ -165,11 +168,6 @@ sub MinifyFiles {
         $FileString .= "$Location:$FileMTime:";
     }
 
-    # also include the config timestamp in the caching to reload the data on config changes
-    my $ConfigTimestamp = $Self->{ConfigObject}->ConfigChecksum();
-
-    $FileString .= $ConfigTimestamp;
-
     my $Filename = $TargetFilenamePrefix . $Self->{MainObject}->MD5sum(
         String => \$FileString,
     );
@@ -286,13 +284,13 @@ sub GetMinifiedFile {
     if ( !$Param{Type} || !$ValidTypeParams{ $Param{Type} } ) {
         $Self->{LogObject}->Log(
             Priority => 'error',
-            Message => "Need Type! Must be one of '" . join( ', ', keys %ValidTypeParams ) . "'."
+            Message  => "Need Type! Must be one of '" . join( ', ', keys %ValidTypeParams ) . "'."
         );
         return;
     }
 
     my $FileMTime = $Self->{MainObject}->FileGetMTime(
-        Location => $Location
+        Location => $Location,
     );
 
     # For the caching, use both filename and mtime to make sure that
@@ -301,7 +299,7 @@ sub GetMinifiedFile {
 
     # check if a cached version exists
     my $CacheContent = $Self->{CacheInternalObject}->Get(
-        Key => $CacheKey
+        Key => $CacheKey,
     );
 
     if ( ref $CacheContent eq 'SCALAR' ) {
@@ -310,7 +308,12 @@ sub GetMinifiedFile {
 
     # no cache available, read and minify file
     my $FileContents = $Self->{MainObject}->FileRead(
-        Location => $Location
+        Location => $Location,
+
+        # It would be more correct to use UTF8 mode, but then the JavaScript::Minifier
+        #   will cause timeouts due to extreme slowness on some UT servers. Disable for now.
+        #   Unicode in the files still works correctly.
+        #Mode     => 'utf8',
     );
 
     if ( ref $FileContents ne 'SCALAR' ) {
@@ -407,6 +410,58 @@ sub MinifyJavaScript {
     return JavaScript::Minifier::minify( input => $Param{Code} );
 }
 
+=item CacheGenerate()
+
+generates the loader cache files for all frontend modules.
+
+    my %GeneratedFiles = $LoaderObject->CacheGenerate();
+
+=cut
+
+sub CacheGenerate {
+    my ( $Self, %Param ) = @_;
+
+    my @Result;
+
+    my $ParamObject = Kernel::System::Web::Request->new(
+        %{$Self},
+        WebRequest => 0,
+    );
+
+    my $TimeObject = Kernel::System::Time->new( %{$Self} );
+
+    my $LayoutObject = Kernel::Output::HTML::Layout->new(
+        %{$Self},
+        TimeObject   => $TimeObject,
+        ParamObject  => $ParamObject,
+        Lang         => 'en',
+        UserTimeZone => '+0',
+    );
+
+    my %AgentFrontends = %{ $Self->{ConfigObject}->Get('Frontend::Module') // {} };
+
+    for my $FrontendModule ( sort { $a cmp $b } keys %AgentFrontends ) {
+        $LayoutObject->{Action} = $FrontendModule;
+        $LayoutObject->LoaderCreateAgentCSSCalls();
+        $LayoutObject->LoaderCreateAgentJSCalls();
+        push @Result, $FrontendModule;
+    }
+
+    my %CustomerFrontends = (
+        %{ $Self->{ConfigObject}->Get('CustomerFrontend::Module') // {} },
+        %{ $Self->{ConfigObject}->Get('PublicFrontend::Module')   // {} },
+    );
+
+    for my $FrontendModule ( sort { $a cmp $b } keys %CustomerFrontends ) {
+        $LayoutObject->{Action} = $FrontendModule;
+        $LayoutObject->LoaderCreateCustomerCSSCalls();
+        $LayoutObject->LoaderCreateCustomerJSCalls();
+        push @Result, $FrontendModule;
+    }
+
+    return @Result;
+}
+
 =item CacheDelete()
 
 deletes all the loader cache files.
@@ -446,8 +501,8 @@ sub CacheDelete {
                 Directory => $Folder,
                 Filter    => 'css-cache',
             );
-            if (@CacheFolder) {
-                push @CacheFoldersList, $CacheFolder[0] if -d $CacheFolder[0];
+            if ( @CacheFolder && -d $CacheFolder[0] ) {
+                push @CacheFoldersList, $CacheFolder[0];
             }
         }
     }
