@@ -1,9 +1,10 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/System/PostMaster/Filter.pm - all functions to add/delete/list pm db filters
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::PostMaster::Filter;
@@ -11,26 +12,55 @@ package Kernel::System::PostMaster::Filter;
 use strict;
 use warnings;
 
-our @ObjectDependencies = (
-    'Kernel::System::DB',
-    'Kernel::System::Log',
-);
-
 =head1 NAME
 
 Kernel::System::PostMaster::Filter
 
-=head1 DESCRIPTION
+=head1 SYNOPSIS
 
 All postmaster database filters
 
 =head1 PUBLIC INTERFACE
 
-=head2 new()
+=over 4
 
-Don't use the constructor directly, use the ObjectManager instead:
+=cut
 
-    my $PMFilterObject = $Kernel::OM->Get('Kernel::System::PostMaster::Filter');
+=item new()
+
+create an object
+
+    use Kernel::Config;
+    use Kernel::System::Encode;
+    use Kernel::System::Log;
+    use Kernel::System::Main;
+    use Kernel::System::DB;
+    use Kernel::System::PostMaster::Filter;
+
+    my $ConfigObject = Kernel::Config->new();
+    my $EncodeObject = Kernel::System::Encode->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+    );
+    my $MainObject = Kernel::System::Main->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+        LogObject    => $LogObject,
+    );
+    my $DBObject = Kernel::System::DB->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+        LogObject    => $LogObject,
+        MainObject   => $MainObject,
+    );
+    my $PMFilterObject = Kernel::System::PostMaster::Filter->new(
+        ConfigObject => $ConfigObject,
+        LogObject    => $LogObject,
+        DBObject     => $DBObject,
+    );
 
 =cut
 
@@ -41,10 +71,15 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
+    # check needed objects
+    for (qw(DBObject ConfigObject LogObject)) {
+        $Self->{$_} = $Param{$_} || die "Got no $_!";
+    }
+
     return $Self;
 }
 
-=head2 FilterList()
+=item FilterList()
 
 get all filter
 
@@ -55,49 +90,30 @@ get all filter
 sub FilterList {
     my ( $Self, %Param ) = @_;
 
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
-    return if !$DBObject->Prepare(
+    return if !$Self->{DBObject}->Prepare(
         SQL => 'SELECT f_name FROM postmaster_filter',
     );
-
     my %Data;
-    while ( my @Row = $DBObject->FetchrowArray() ) {
+    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $Data{ $Row[0] } = $Row[0];
     }
-
     return %Data;
 }
 
-=head2 FilterAdd()
+=item FilterAdd()
 
 add a filter
 
     $PMFilterObject->FilterAdd(
         Name           => 'some name',
         StopAfterMatch => 0,
-        Match = [
-            {
-                Key   => 'Subject',
-                Value => '^ADV: 123',
+        Match = {
+            From => 'email@example.com',
+            Subject => '^ADV: 123',
         },
-            ...
-        ],
-        Not = [
-            {
-                Key   => 'Subject',
-                Value => '1',
+        Set {
+            'X-OTRS-Queue' => 'Some::Queue',
         },
-            ...
-        ],
-        Set = [
-            {
-                Key   => 'X-OTRS-Queue',
-                Value => 'Some::Queue',
-            },
-            ...
-        ],
     );
 
 =cut
@@ -108,7 +124,7 @@ sub FilterAdd {
     # check needed stuff
     for (qw(Name StopAfterMatch Match Set)) {
         if ( !defined $Param{$_} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -116,33 +132,26 @@ sub FilterAdd {
         }
     }
 
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
-    my @Not = @{ $Param{Not} || [] };
+    my %Not = %{ $Param{Not} || {} };
 
     for my $Type (qw(Match Set)) {
-
-        my @Data = @{ $Param{$Type} };
-
-        for my $Index ( 0 .. ( scalar @Data ) - 1 ) {
-
-            return if !$DBObject->Do(
+        my %Data = %{ $Param{$Type} };
+        for my $Key ( sort keys %Data ) {
+            return if !$Self->{DBObject}->Do(
                 SQL =>
                     'INSERT INTO postmaster_filter (f_name, f_stop, f_type, f_key, f_value, f_not)'
                     . ' VALUES (?, ?, ?, ?, ?, ?)',
                 Bind => [
                     \$Param{Name}, \$Param{StopAfterMatch}, \$Type,
-                    \$Data[$Index]->{Key}, \$Data[$Index]->{Value}, \$Not[$Index]->{Value},
+                    \$Key, \$Data{$Key}, \$Not{$Key}
                 ],
             );
         }
     }
-
     return 1;
 }
 
-=head2 FilterDelete()
+=item FilterDelete()
 
 delete a filter
 
@@ -158,7 +167,7 @@ sub FilterDelete {
     # check needed stuff
     for (qw(Name)) {
         if ( !defined $Param{$_} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -166,18 +175,14 @@ sub FilterDelete {
         }
     }
 
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
-    return if !$DBObject->Do(
+    return if !$Self->{DBObject}->Do(
         SQL  => 'DELETE FROM postmaster_filter WHERE f_name = ?',
         Bind => [ \$Param{Name} ],
     );
-
     return 1;
 }
 
-=head2 FilterGet()
+=item FilterGet()
 
 get filter properties, returns HASH ref Match and Set
 
@@ -193,7 +198,7 @@ sub FilterGet {
     # check needed stuff
     for (qw(Name)) {
         if ( !defined $Param{$_} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -201,46 +206,34 @@ sub FilterGet {
         }
     }
 
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
-    return if !$DBObject->Prepare(
+    return if !$Self->{DBObject}->Prepare(
         SQL =>
-            'SELECT f_type, f_key, f_value, f_name, f_stop, f_not'
-            . ' FROM postmaster_filter'
-            . ' WHERE f_name = ?'
-            . ' ORDER BY f_key, f_value',
+            'SELECT f_type, f_key, f_value, f_name, f_stop, f_not FROM postmaster_filter WHERE f_name = ?',
         Bind => [ \$Param{Name} ],
     );
-
     my %Data;
-    while ( my @Row = $DBObject->FetchrowArray() ) {
-        push @{ $Data{ $Row[0] } }, {
-            Key   => $Row[1],
-            Value => $Row[2],
-        };
-        $Data{Name}           = $Row[3];
-        $Data{StopAfterMatch} = $Row[4];
+    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+        $Data{ $Row[0] }->{ $Row[1] } = $Row[2];
+        $Data{Name}                   = $Row[3];
+        $Data{StopAfterMatch}         = $Row[4];
 
         if ( $Row[0] eq 'Match' ) {
-            push @{ $Data{Not} }, {
-                Key   => $Row[1],
-                Value => $Row[5],
-            };
+            $Data{Not}->{ $Row[1] } = $Row[5];
         }
     }
-
     return %Data;
 }
 
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
