@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/Spelling.pm - the global spelling module
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,12 +13,7 @@ use strict;
 use warnings;
 use utf8;
 
-our @ObjectDependencies = (
-    'Kernel::Config',
-    'Kernel::System::Encode',
-    'Kernel::System::FileTemp',
-    'Kernel::System::Log',
-);
+use Kernel::System::FileTemp;
 
 =head1 NAME
 
@@ -36,11 +32,26 @@ Currently, ispell and aspell are supported as spellchecker backends.
 
 =item new()
 
-create an object. Do not use it directly, instead use:
+create a spelling object
 
-    use Kernel::System::ObjectManager;
-    local $Kernel::OM = Kernel::System::ObjectManager->new();
-    my $SpellingObject = $Kernel::OM->Get('Kernel::System::Spelling');
+    use Kernel::Config;
+    use Kernel::System::Encode;
+    use Kernel::System::Log;
+    use Kernel::System::Spelling;
+
+    my $ConfigObject = Kernel::Config->new();
+    my $EncodeObject = Kernel::System::Encode->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+    );
+    my $SpellingObject = Kernel::System::Spelling->new(
+        ConfigObject => $ConfigObject,
+        LogObject    => $LogObject,
+        EncodeObject => $EncodeObject,
+    );
 
 =cut
 
@@ -51,6 +62,19 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
+    $Self->{Debug} = 0;
+
+    # get needed objects
+    for (qw(ConfigObject LogObject EncodeObject)) {
+        $Self->{$_} = $Param{$_} || die "Got no $_!";
+    }
+
+    # create file template object
+    $Self->{FileTempObject} = Kernel::System::FileTemp->new( %{$Self} );
+
+    # spell checker config options
+    $Self->{SpellChecker} = $Self->{ConfigObject}->Get('SpellCheckerBin') || 'ispell';
+
     return $Self;
 }
 
@@ -80,12 +104,14 @@ sub Check {
     my ( $Self, %Param ) = @_;
 
     # check needed stuff
-    if ( !defined $Param{Text} ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => "Need Text!"
-        );
-        return;
+    for (qw(Text)) {
+        if ( !$Param{$_} ) {
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
+            return;
+        }
     }
 
     # default ignored words
@@ -94,15 +120,9 @@ sub Check {
         caldera php perl java html unsubscribe queue event day month year ticket
     );
 
-    # get config object
-    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
-
-    # spell checker config options
-    my $SpellChecker = $ConfigObject->Get('SpellCheckerBin') || 'ispell';
-
     # add configured ignored words
-    if ( ref $ConfigObject->Get('SpellCheckerIgnore') eq 'ARRAY' ) {
-        for ( @{ $ConfigObject->Get('SpellCheckerIgnore') } ) {
+    if ( ref $Self->{ConfigObject}->Get('SpellCheckerIgnore') eq 'ARRAY' ) {
+        for ( @{ $Self->{ConfigObject}->Get('SpellCheckerIgnore') } ) {
             push @Ignore, $_;
         }
     }
@@ -115,7 +135,7 @@ sub Check {
     $Param{Text} =~ s/^>.*$//gm;
 
     # ispell encoding:
-    if ( $SpellChecker =~ /ispell/ ) {
+    if ( $Self->{SpellChecker} =~ /ispell/ ) {
         $Param{Text} =~ s/ä/a"/g;
         $Param{Text} =~ s/ö/o"/g;
         $Param{Text} =~ s/ü/u"/g;
@@ -126,54 +146,51 @@ sub Check {
     }
 
     # check if spell checker exists in file system
-    if ( !-e $ConfigObject->Get('SpellCheckerBin') ) {
+    if ( !-e $Self->{ConfigObject}->Get('SpellCheckerBin') ) {
         $Self->{Error} = 1;
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'error',
             Message  => "Can't find spellchecker ("
-                . $ConfigObject->Get('SpellCheckerBin') . "): $!",
+                . $Self->{ConfigObject}->Get('SpellCheckerBin') . "): $!",
         );
         return;
     }
 
     # add -a
-    $SpellChecker .= ' -a ';
+    $Self->{SpellChecker} .= ' -a ';
 
     # set dict
     if ( $Param{SpellLanguage} ) {
-        $SpellChecker .= " -d $Param{SpellLanguage}";
+        $Self->{SpellChecker} .= " -d $Param{SpellLanguage}";
     }
 
     # get spell output
 
     # write text to file and read it with (i|a)spell
     # - can't use IPC::Open* because it's not working with mod_perl* :-/
-    my ( $FH, $TmpFile ) = $Kernel::OM->Get('Kernel::System::FileTemp')->TempFile();
+    my ( $FH, $TmpFile ) = $Self->{FileTempObject}->TempFile();
     if ( !$FH ) {
         $Self->{Error} = 1;
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'error',
             Message  => "Can't write spell tmp text to $TmpFile: $!",
         );
         return;
     }
 
-    # get encode object
-    my $EncodeObject = $Kernel::OM->Get('Kernel::System::Encode');
-
-    $EncodeObject->EncodeOutput( \$Param{Text} );
+    $Self->{EncodeObject}->EncodeOutput( \$Param{Text} );
     print $FH $Param{Text};
 
     # aspell encoding
-    if ( $SpellChecker =~ /aspell/ ) {
-        $SpellChecker .= ' --encoding=utf-8';
+    if ( $Self->{SpellChecker} =~ /aspell/ ) {
+        $Self->{SpellChecker} .= ' --encoding=utf-8';
     }
 
     # open spell checker
     my $Spell;
-    if ( !open( $Spell, "-|", "$SpellChecker < $TmpFile" ) ) {    ## no critic
+    if ( !open( $Spell, "-|", "$Self->{SpellChecker} < $TmpFile" ) ) {    ## no critic
         $Self->{Error} = 1;
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'error',
             Message  => "Can't open spellchecker: $!",
         );
@@ -185,14 +202,13 @@ sub Check {
     my $CurrentLine = 0;
     my %Data;
     while ( my $Line = <$Spell> ) {
-
         $CurrentLine++;
 
         # set utf8 stamp if running in utf8 mode
-        $EncodeObject->EncodeInput( \$Line );
+        $Self->{EncodeObject}->EncodeInput( \$Line );
 
         # ispell encoding:
-        if ( $SpellChecker =~ /ispell/ ) {
+        if ( $Self->{SpellChecker} =~ /ispell/ ) {
             $Line =~ s/a"/ä/g;
             $Line =~ s/o"/ö/g;
             $Line =~ s/u"/ü/g;
@@ -255,9 +271,7 @@ sub Check {
             }
         }
     }
-
     close($Spell);
-
     return %Data;
 }
 
