@@ -2,8 +2,6 @@
 # Kernel/System/Ticket/Event/TriggerEscalationStopEvents.pm - trigger escalation stop events
 # Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
-# $Id: TriggerEscalationStopEvents.pm,v 1.2.2.1 2012-09-27 14:14:34 mb Exp $
-# --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
 # did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
@@ -14,9 +12,6 @@ package Kernel::System::Ticket::Event::TriggerEscalationStopEvents;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.2.2.1 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -41,13 +36,19 @@ sub Run {
     # check needed stuff
     for my $Needed (qw(Event UserID Config)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $Needed!"
+            );
             return;
         }
     }
     for my $Needed (qw(OldTicketData TicketID)) {
         if ( !$Param{Data}->{$Needed} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed in Data!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $Needed in Data!"
+            );
             return;
         }
     }
