@@ -46,7 +46,10 @@ sub FormIDRemove {
     my ( $Self, %Param ) = @_;
 
     if ( !$Param{FormID} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need FormID!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need FormID!'
+        );
         return;
     }
 
@@ -56,7 +59,9 @@ sub FormIDRemove {
     );
     my @Data;
     for my $File (@List) {
-        $Self->{MainObject}->FileDelete( Location => $File, );
+        $Self->{MainObject}->FileDelete(
+            Location => $File,
+        );
     }
     return 1;
 }
@@ -66,7 +71,10 @@ sub FormIDAddFile {
 
     for (qw(FormID Filename Content ContentType)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -86,21 +94,21 @@ sub FormIDAddFile {
         Filename   => "$Param{FormID}.$Param{Filename}",
         Content    => \$Param{Content},
         Mode       => 'binmode',
-        Permission => '644',
+        Permission => '640',
     );
     return if !$Self->{MainObject}->FileWrite(
         Directory  => $Self->{TempDir},
         Filename   => "$Param{FormID}.$Param{Filename}.ContentType",
         Content    => \$Param{ContentType},
         Mode       => 'binmode',
-        Permission => '644',
+        Permission => '640',
     );
     return if !$Self->{MainObject}->FileWrite(
         Directory  => $Self->{TempDir},
         Filename   => "$Param{FormID}.$Param{Filename}.ContentID",
         Content    => \$ContentID,
         Mode       => 'binmode',
-        Permission => '644',
+        Permission => '640',
     );
     return 1;
 }
@@ -110,7 +118,10 @@ sub FormIDRemoveFile {
 
     for (qw(FormID FileID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -136,7 +147,10 @@ sub FormIDGetAllFilesData {
     my ( $Self, %Param ) = @_;
 
     if ( !$Param{FormID} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need FormID!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need FormID!'
+        );
         return;
     }
 
@@ -160,7 +174,9 @@ sub FormIDGetAllFilesData {
         if ($FileSize) {
 
             # remove meta data in files
-            $FileSize = $FileSize - 30 if ( $FileSize > 30 );
+            if ( $FileSize > 30 ) {
+                $FileSize = $FileSize - 30
+            }
             if ( $FileSize > 1048576 ) {    # 1024 * 1024
                 $FileSize = sprintf "%.1f MBytes", ( $FileSize / 1048576 );    # 1024 * 1024
             }
@@ -173,19 +189,19 @@ sub FormIDGetAllFilesData {
         }
         my $Content = $Self->{MainObject}->FileRead(
             Location => $File,
-            Mode     => 'binmode',    # optional - binmode|utf8
+            Mode     => 'binmode',                                             # optional - binmode|utf8
         );
         next if !$Content;
 
         my $ContentType = $Self->{MainObject}->FileRead(
             Location => "$File.ContentType",
-            Mode     => 'binmode',             # optional - binmode|utf8
+            Mode     => 'binmode',                                             # optional - binmode|utf8
         );
         next if !$ContentType;
 
         my $ContentID = $Self->{MainObject}->FileRead(
             Location => "$File.ContentID",
-            Mode     => 'binmode',             # optional - binmode|utf8
+            Mode     => 'binmode',                                             # optional - binmode|utf8
         );
         next if !$ContentID;
 
@@ -216,7 +232,10 @@ sub FormIDGetAllFilesMeta {
     my ( $Self, %Param ) = @_;
 
     if ( !$Param{FormID} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need FormID!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need FormID!'
+        );
         return;
     }
 
@@ -240,7 +259,9 @@ sub FormIDGetAllFilesMeta {
         if ($FileSize) {
 
             # remove meta data in files
-            $FileSize = $FileSize - 30 if ( $FileSize > 30 );
+            if ( $FileSize > 30 ) {
+                $FileSize = $FileSize - 30
+            }
             if ( $FileSize > 1048576 ) {    # 1024 * 1024
                 $FileSize = sprintf "%.1f MBytes", ( $FileSize / 1048576 );    # 1024 * 1024
             }
@@ -254,13 +275,13 @@ sub FormIDGetAllFilesMeta {
 
         my $ContentType = $Self->{MainObject}->FileRead(
             Location => "$File.ContentType",
-            Mode     => 'binmode',             # optional - binmode|utf8
+            Mode     => 'binmode',                                             # optional - binmode|utf8
         );
         next if !$ContentType;
 
         my $ContentID = $Self->{MainObject}->FileRead(
             Location => "$File.ContentID",
-            Mode     => 'binmode',             # optional - binmode|utf8
+            Mode     => 'binmode',                                             # optional - binmode|utf8
         );
         next if !$ContentID;
 
