@@ -34,9 +34,8 @@ PACKAGE_TMP_SPEC="/tmp/$PACKAGE.spec"
 RPM_BUILD="rpmbuild"
 #RPM_BUILD="rpm"
 
-SUPPORT_PACKAGE="http://ftp.otrs.org/pub/otrs/packages/Support-1.4.4.opm"
 #IPHONE_PACKAGE="http://ftp.otrs.org/pub/otrs/packages/iPhoneHandle-1.1.1.opm"
-MANUAL_EN="http://ftp.otrs.org/pub/otrs/doc/doc-admin/3.2/en/pdf/otrs_admin_book.pdf"
+MANUAL_EN="http://ftp.otrs.org/pub/otrs/doc/doc-admin/3.3/en/pdf/otrs_admin_book.pdf"
 #MANUAL_DE="http://ftp.otrs.org/pub/otrs/doc/doc-admin/3.2/de/pdf/otrs_admin_book.pdf"
 
 
@@ -162,11 +161,6 @@ bin/otrs.CheckSum.pl -a create
 # add pre installed packages
 mkdir var/packages/
 
-if test $SUPPORT_PACKAGE; then
-    wget "$SUPPORT_PACKAGE" || exit 1;
-    mv Support*.opm var/packages/
-fi
-
 if test $IPHONE_PACKAGE; then
     wget "$IPHONE_PACKAGE" || exit 1;
     mv iPhoneHandle*.opm var/packages/
@@ -261,24 +255,6 @@ rm ~/.rpmmacros || exit 1;
 mv $SYSTEM_RPM_DIR/*/$PACKAGE*$VERSION*$RELEASE*.rpm $PACKAGE_DEST_DIR/RPMS/fedora/4/
 mv $SYSTEM_SRPM_DIR/$PACKAGE*$VERSION*$RELEASE*.src.rpm $PACKAGE_DEST_DIR/SRPMS/fedora/4/
 
-# --
-# build RHEL5 rpm
-# --
-echo "Building RHEL5 rpm..."
-cp $ARCHIVE_DIR/scripts/redhat-rpmmacros ~/.rpmmacros || exit 1
-specfile=$PACKAGE_TMP_SPEC
-cat $ARCHIVE_DIR/scripts/rhel5-otrs.spec | sed "s/^Version:.*/Version:      $VERSION/" | sed "s/^Release:.*/Release:      $RELEASE/" > $specfile.tmp
-# replace sourced files
-perl -e "open(SPEC, '< $specfile.tmp');while(<SPEC>){\$spec.=\$_;};open(IN, '< $FILES');while(<IN>){\$i.=\$_;}\$spec=~s/<FILES>/\$i/g;print \$spec;" > $specfile.tmp1
-# replace package description
-perl -e "open(SPEC, '< $specfile.tmp1');while(<SPEC>){\$spec.=\$_;};open(IN, '< $DESCRIPTION');while(<IN>){\$i.=\$_;}\$spec=~s/<DESCRIPTION>/\$i/g;print \$spec;" > $specfile
-$RPM_BUILD -ba --clean $specfile || exit 1;
-rm $specfile || exit 1;
-rm ~/.rpmmacros || exit 1;
-
-mv $SYSTEM_RPM_DIR/*/$PACKAGE*$VERSION*$RELEASE*.rpm $PACKAGE_DEST_DIR/RPMS/rhel/5/
-mv $SYSTEM_SRPM_DIR/$PACKAGE*$VERSION*$RELEASE*.src.rpm $PACKAGE_DEST_DIR/SRPMS/rhel/5/
-
 # --
 # build RHEL6 rpm
 # --
@@ -328,12 +304,9 @@ if which md5sum >> /dev/null; then
 else
     echo "No md5sum found in \$PATH!"
 fi
-echo "-----------------------------------------------------------------";
-echo "Note: You may have to tag your cvs tree:     cvs tag rel-2_x_x";
-echo "Note: You may have to branch your cvs tree:  cvs tag -b rel-2_x";
-echo "Note: To delete a tag:                       cvs tag -d rel-2_x_x";
-echo "Note: To check out by timestamp:             cvs co -r rel-2_x -D \"2008-10-02 17:00\" otrs";
-echo "-----------------------------------------------------------------";
+echo "--------------------------------------------------------------------------";
+echo "Note: You may have to tag your git tree: git tag rel-3_x_x -a -m \"3.x.x\"";
+echo "--------------------------------------------------------------------------";
 
 # --
 # cleanup
